# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class PaymentTypes(Enum):
    """An enumeration representing different categories.

    :cvar PAY_LATER: "PAY_LATER"
    :vartype PAY_LATER: str
    :cvar PAY_NOW: "PAY_NOW"
    :vartype PAY_NOW: str
    """

    PAY_LATER = "PAY_LATER"
    PAY_NOW = "PAY_NOW"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, PaymentTypes._member_map_.values()))


@JsonMap({})
class PaymentDto(BaseModel):
    """Payment terms and conditions for this product.

    :param payment_types: payment_types, defaults to None
    :type payment_types: List[PaymentTypes], optional
    """

    def __init__(self, payment_types: List[PaymentTypes] = None):
        if payment_types is not None:
            self.payment_types = self._define_list(payment_types, PaymentTypes)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .cancellation_dto import CancellationDto
from .meal_plan_dto import MealPlanDto
from .payment_dto import PaymentDto


@JsonMap({})
class PoliciesDto(BaseModel):
    """The policies for this product.

    :param cancellation: The cancellation policy for this product., defaults to None
    :type cancellation: CancellationDto, optional
    :param meal_plan: The meal plan policy for this product., defaults to None
    :type meal_plan: MealPlanDto, optional
    :param payment: Payment terms and conditions for this product., defaults to None
    :type payment: PaymentDto, optional
    """

    def __init__(
        self,
        cancellation: CancellationDto = None,
        meal_plan: MealPlanDto = None,
        payment: PaymentDto = None,
    ):
        if cancellation is not None:
            self.cancellation = self._define_object(cancellation, CancellationDto)
        if meal_plan is not None:
            self.meal_plan = self._define_object(meal_plan, MealPlanDto)
        if payment is not None:
            self.payment = self._define_object(payment, PaymentDto)



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class BlockOutputDto(BaseModel):
    """The object containing all the relevant information for the combination of room, policy, meal and occupancy that determines the price."
    A block is the unique entity you book with booking.com.

    :param block_id: block_id, defaults to None
    :type block_id: str, optional
    :param breakfast_included: breakfast_included, defaults to None
    :type breakfast_included: bool, optional
    """

    def __init__(self, block_id: str = None, breakfast_included: bool = None):
        if block_id is not None:
            self.block_id = block_id
        if breakfast_included is not None:
            self.breakfast_included = breakfast_included



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class RoomSizeDto(BaseModel):
    """RoomSizeDto

    :param metre_square: metre_square, defaults to None
    :type metre_square: float, optional
    """

    def __init__(self, metre_square: float = None):
        if metre_square is not None:
            self.metre_square = metre_square



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .bed_configuration_dto import BedConfigurationDto


@JsonMap({})
class BedOptionDto(BaseModel):
    """Lists all possible bedding options for this room or apartment.

    :param bed_configurations: Lists all alternative bed configurations that are supported., defaults to None
    :type bed_configurations: List[BedConfigurationDto], optional
    :param has_bathroom: Flags if this area includes its own bathroom., defaults to None
    :type has_bathroom: bool, optional
    :param is_bedroom: Flags if this area is marked as a bedroom, otherwise, it should be considered a living room., defaults to None
    :type is_bedroom: bool, optional
    """

    def __init__(
        self,
        bed_configurations: List[BedConfigurationDto] = None,
        has_bathroom: bool = None,
        is_bedroom: bool = None,
    ):
        if bed_configurations is not None:
            self.bed_configurations = self._define_list(
                bed_configurations, BedConfigurationDto
            )
        if has_bathroom is not None:
            self.has_bathroom = has_bathroom
        if is_bedroom is not None:
            self.is_bedroom = is_bedroom



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .meta import Meta
from .hotel_availability_output_dto import HotelAvailabilityOutputDto


@JsonMap({})
class ResponseOutputV2HotelAvailabilityOutputDto(BaseModel):
    """ResponseOutputV2HotelAvailabilityOutputDto

    :param meta: meta, defaults to None
    :type meta: Meta, optional
    :param result: result, defaults to None
    :type result: List[HotelAvailabilityOutputDto], optional
    """

    def __init__(
        self, meta: Meta = None, result: List[HotelAvailabilityOutputDto] = None
    ):
        if meta is not None:
            self.meta = self._define_object(meta, Meta)
        if result is not None:
            self.result = self._define_list(result, HotelAvailabilityOutputDto)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class FacilityDtoAttributes(Enum):
    """An enumeration representing different categories.

    :cvar OFFSITE: "OFFSITE"
    :vartype OFFSITE: str
    :cvar PAID: "PAID"
    :vartype PAID: str
    """

    OFFSITE = "OFFSITE"
    PAID = "PAID"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, FacilityDtoAttributes._member_map_.values()))


@JsonMap({"id_": "id"})
class FacilityDto(BaseModel):
    """The list of facilities available in this property. Requires `{"extras":["facilities"]}`.

    :param id_: A signed integer number that uniquely identifies an accommodation property facility. Examples of facilities are: Parking, Restaurant, Room service etc. , defaults to None
    :type id_: int, optional
    :param attributes: List of optional attributes for this facility., defaults to None
    :type attributes: List[FacilityDtoAttributes], optional
    """

    def __init__(self, id_: int = None, attributes: List[FacilityDtoAttributes] = None):
        if id_ is not None:
            self.id_ = id_
        if attributes is not None:
            self.attributes = self._define_list(attributes, FacilityDtoAttributes)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .translated_string import TranslatedString


@JsonMap({})
class TruncatedString(BaseModel):
    """The translated description text of this accommodation property in the requested languages.
    The maximum number of characters returned may be limited by contract.


    :param truncate: truncate, defaults to None
    :type truncate: bool, optional
    :param translated_string: Translated description of this room. The maximum number of characters returned may be limited by contract., defaults to None
    :type translated_string: TranslatedString, optional
    """

    def __init__(
        self, truncate: bool = None, translated_string: TranslatedString = None
    ):
        if truncate is not None:
            self.truncate = truncate
        if translated_string is not None:
            self.translated_string = self._define_object(
                translated_string, TranslatedString
            )



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .extra_charges_dto_list_charge_dto import ExtraChargesDtoListChargeDto


@JsonMap({})
class PriceDataDtoListChargeDto(BaseModel):
    """The price components of this product or selection of products.
    'base' and 'extra_charges' are returned only when explicitly requested (via 'extras=extra_charges').


    :param base: The base price. Does not include any extra charges., defaults to None
    :type base: float, optional
    :param book: The price that will be charged by Booking.com., defaults to None
    :type book: float, optional
    :param total: The total price. Includes all extra charges., defaults to None
    :type total: float, optional
    :param extra_charges: The charge breakdown. Includes taxes and fees., defaults to None
    :type extra_charges: ExtraChargesDtoListChargeDto, optional
    """

    def __init__(
        self,
        base: float = None,
        book: float = None,
        total: float = None,
        extra_charges: ExtraChargesDtoListChargeDto = None,
    ):
        if base is not None:
            self.base = base
        if book is not None:
            self.book = book
        if total is not None:
            self.total = total
        if extra_charges is not None:
            self.extra_charges = self._define_object(
                extra_charges, ExtraChargesDtoListChargeDto
            )



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class Type(Enum):
    """An enumeration representing different categories.

    :cvar FREE_CANCELLATION: "FREE_CANCELLATION"
    :vartype FREE_CANCELLATION: str
    :cvar NON_REFUNDABLE: "NON_REFUNDABLE"
    :vartype NON_REFUNDABLE: str
    :cvar SPECIAL_CONDITIONS: "SPECIAL_CONDITIONS"
    :vartype SPECIAL_CONDITIONS: str
    """

    FREE_CANCELLATION = "FREE_CANCELLATION"
    NON_REFUNDABLE = "NON_REFUNDABLE"
    SPECIAL_CONDITIONS = "SPECIAL_CONDITIONS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Type._member_map_.values()))


@JsonMap({"type_": "type"})
class CancellationDto(BaseModel):
    """The cancellation policy for this product.

    :param free_cancellation_until: Until when the order for this product can be cancelled for free., defaults to None
    :type free_cancellation_until: str, optional
    :param type_: The cancellation scheme supported by this product., defaults to None
    :type type_: Type, optional
    """

    def __init__(self, free_cancellation_until: str = None, type_: Type = None):
        if free_cancellation_until is not None:
            self.free_cancellation_until = free_cancellation_until
        if type_ is not None:
            self.type_ = self._enum_matching(type_, Type.list(), "type_")



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class RoomMaximumOccupancyDto(BaseModel):
    """Occupancy limits and options.

    :param adults: Maximum number of adults allowed., defaults to None
    :type adults: int, optional
    :param children: Maximum number of children allowed (children will be typically defined by being under 18 years of age)., defaults to None
    :type children: int, optional
    :param total_guests: **DEPRECATED** Total capacity of adults + children allowed., defaults to None
    :type total_guests: int, optional
    """

    def __init__(
        self, adults: int = None, children: int = None, total_guests: int = None
    ):
        if adults is not None:
            self.adults = adults
        if children is not None:
            self.children = children
        if total_guests is not None:
            self.total_guests = total_guests



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .charge_dto import ChargeDto


@JsonMap({})
class ExtraChargesDtoListChargeDto(BaseModel):
    """The charge breakdown. Includes taxes and fees.

    :param excluded: Charges not included in 'book'., defaults to None
    :type excluded: List[ChargeDto], optional
    :param included: Charges included in 'book'., defaults to None
    :type included: List[ChargeDto], optional
    :param conditional: conditional, defaults to None
    :type conditional: List[ChargeDto], optional
    """

    def __init__(
        self,
        excluded: List[ChargeDto] = None,
        included: List[ChargeDto] = None,
        conditional: List[ChargeDto] = None,
    ):
        if excluded is not None:
            self.excluded = self._define_list(excluded, ChargeDto)
        if included is not None:
            self.included = self._define_list(included, ChargeDto)
        if conditional is not None:
            self.conditional = self._define_list(conditional, ChargeDto)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .local_time import LocalTime


@JsonMap({})
class CheckinCheckoutTimesDto(BaseModel):
    """CheckinCheckoutTimesDto

    :param checkin_from: The time till when checkout can be done at this property., defaults to None
    :type checkin_from: LocalTime, optional
    :param checkin_to: The time till when checkout can be done at this property., defaults to None
    :type checkin_to: LocalTime, optional
    :param checkout_from: The time till when checkout can be done at this property., defaults to None
    :type checkout_from: LocalTime, optional
    :param checkout_to: The time till when checkout can be done at this property., defaults to None
    :type checkout_to: LocalTime, optional
    """

    def __init__(
        self,
        checkin_from: LocalTime = None,
        checkin_to: LocalTime = None,
        checkout_from: LocalTime = None,
        checkout_to: LocalTime = None,
    ):
        if checkin_from is not None:
            self.checkin_from = self._define_object(checkin_from, LocalTime)
        if checkin_to is not None:
            self.checkin_to = self._define_object(checkin_to, LocalTime)
        if checkout_from is not None:
            self.checkout_from = self._define_object(checkout_from, LocalTime)
        if checkout_to is not None:
            self.checkout_to = self._define_object(checkout_to, LocalTime)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .bedroom_dto import BedroomDto
from .room_occupancy_dto import RoomOccupancyDto
from .room_size_dto import RoomSizeDto


@JsonMap({})
class RoomInfoDto(BaseModel):
    """RoomInfoDto

    :param bathroom_count: bathroom_count, defaults to None
    :type bathroom_count: float, optional
    :param bedroom_count: bedroom_count, defaults to None
    :type bedroom_count: float, optional
    :param bedrooms: bedrooms, defaults to None
    :type bedrooms: List[BedroomDto], optional
    :param occupancy: occupancy, defaults to None
    :type occupancy: RoomOccupancyDto, optional
    :param room_size: room_size, defaults to None
    :type room_size: RoomSizeDto, optional
    :param room_type_id: room_type_id, defaults to None
    :type room_type_id: int, optional
    """

    def __init__(
        self,
        bathroom_count: float = None,
        bedroom_count: float = None,
        bedrooms: List[BedroomDto] = None,
        occupancy: RoomOccupancyDto = None,
        room_size: RoomSizeDto = None,
        room_type_id: int = None,
    ):
        if bathroom_count is not None:
            self.bathroom_count = bathroom_count
        if bedroom_count is not None:
            self.bedroom_count = bedroom_count
        if bedrooms is not None:
            self.bedrooms = self._define_list(bedrooms, BedroomDto)
        if occupancy is not None:
            self.occupancy = self._define_object(occupancy, RoomOccupancyDto)
        if room_size is not None:
            self.room_size = self._define_object(room_size, RoomSizeDto)
        if room_type_id is not None:
            self.room_type_id = room_type_id



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .translated_string import TranslatedString


@JsonMap({})
class TranslationInformation(BaseModel):
    """Text containing important information about the property. The value is translated in the requested languages.

    :param translated_string: Translated description of this room. The maximum number of characters returned may be limited by contract., defaults to None
    :type translated_string: TranslatedString, optional
    :param non_lazy_translations: non_lazy_translations, defaults to None
    :type non_lazy_translations: dict, optional
    """

    def __init__(
        self,
        translated_string: TranslatedString = None,
        non_lazy_translations: dict = None,
    ):
        if translated_string is not None:
            self.translated_string = self._define_object(
                translated_string, TranslatedString
            )
        if non_lazy_translations is not None:
            self.non_lazy_translations = non_lazy_translations



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelAvailabilityOutputDto(BaseModel):
    """HotelAvailabilityOutputDto

    :param hotel_id: The unique identifier of this hotel., defaults to None
    :type hotel_id: int, optional
    :param hotel_currency_code: The currency code of the hotel's currency., defaults to None
    :type hotel_currency_code: str, optional
    :param price: The display price of the room in this hotel., defaults to None
    :type price: float, optional
    :param net_price: The net price (price without charges) of the room in this hotel., defaults to None
    :type net_price: float, optional
    """

    def __init__(
        self,
        hotel_id: int = None,
        hotel_currency_code: str = None,
        price: float = None,
        net_price: float = None,
    ):
        if hotel_id is not None:
            self.hotel_id = hotel_id
        if hotel_currency_code is not None:
            self.hotel_currency_code = hotel_currency_code
        if price is not None:
            self.price = price
        if net_price is not None:
            self.net_price = net_price



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .translation_information import TranslationInformation
from .truncated_string import TruncatedString


@JsonMap({})
class DescriptionDto(BaseModel):
    """Textual information about the accommodation. Requires `{"extras":["description"]}`.

    :param important_information: Text containing important information about the property. The value is translated in the requested languages., defaults to None
    :type important_information: TranslationInformation, optional
    :param license_numbers: List of all the license numbers of this accommodation property., defaults to None
    :type license_numbers: List[str], optional
    :param text: The translated description text of this accommodation property in the requested languages. The maximum number of characters returned may be limited by contract. , defaults to None
    :type text: TruncatedString, optional
    """

    def __init__(
        self,
        important_information: TranslationInformation = None,
        license_numbers: List[str] = None,
        text: TruncatedString = None,
    ):
        if important_information is not None:
            self.important_information = self._define_object(
                important_information, TranslationInformation
            )
        if license_numbers is not None:
            self.license_numbers = license_numbers
        if text is not None:
            self.text = self._define_object(text, TruncatedString)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class StarsType(Enum):
    """An enumeration representing different categories.

    :cvar ESTIMATED_BY_ACCOMMODATION: "ESTIMATED_BY_ACCOMMODATION"
    :vartype ESTIMATED_BY_ACCOMMODATION: str
    :cvar ESTIMATED_BY_BOOKING: "ESTIMATED_BY_BOOKING"
    :vartype ESTIMATED_BY_BOOKING: str
    :cvar OFFICIAL: "OFFICIAL"
    :vartype OFFICIAL: str
    """

    ESTIMATED_BY_ACCOMMODATION = "ESTIMATED_BY_ACCOMMODATION"
    ESTIMATED_BY_BOOKING = "ESTIMATED_BY_BOOKING"
    OFFICIAL = "OFFICIAL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, StarsType._member_map_.values()))


@JsonMap({})
class RatingDto(BaseModel):
    """RatingDto

    :param number_of_reviews: Number of validated reviews for this accommodation., defaults to None
    :type number_of_reviews: int, optional
    :param preferred: Boolean value is "true" if this accommodation is in the Booking.com's preferred program and "false" otherwise., defaults to None
    :type preferred: bool, optional
    :param review_score: A decimal number indicating the current review score of this accommodation property, in the range 1..10., defaults to None
    :type review_score: float, optional
    :param stars: Number of stars of this accommodation property., defaults to None
    :type stars: float, optional
    :param stars_type: An enumerated value describing which type of stars this accommodation has., defaults to None
    :type stars_type: StarsType, optional
    """

    def __init__(
        self,
        number_of_reviews: int = None,
        preferred: bool = None,
        review_score: float = None,
        stars: float = None,
        stars_type: StarsType = None,
    ):
        if number_of_reviews is not None:
            self.number_of_reviews = number_of_reviews
        if preferred is not None:
            self.preferred = preferred
        if review_score is not None:
            self.review_score = review_score
        if stars is not None:
            self.stars = stars
        if stars_type is not None:
            self.stars_type = self._enum_matching(
                stars_type, StarsType.list(), "stars_type"
            )



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .lazy_translated_string import LazyTranslatedString
from .coordinates_dto import CoordinatesDto


@JsonMap({})
class LocationDto(BaseModel):
    """All location related information of this accommodation property.

    :param address: Translated accommodation address., defaults to None
    :type address: LazyTranslatedString, optional
    :param city: A signed integer number that uniquely identifies a city., defaults to None
    :type city: int, optional
    :param coordinates: A signed integer number that uniquely identifies a city., defaults to None
    :type coordinates: CoordinatesDto, optional
    :param country: A two-letter code that uniquely identifies a country. This code is defined by the ISO 3166-1 alpha-2 standard (ISO2) as described here: https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2. , defaults to None
    :type country: str, optional
    :param districts: A signed integer number that uniquely identifies a district. Typically, districts define known areas within a city., defaults to None
    :type districts: List[int], optional
    :param postal_code: postal_code, defaults to None
    :type postal_code: str, optional
    :param regions: A signed integer number that uniquely identifies a geographical region. Regions usually define official administrative areas within a country, but may also include multiple countries and in some cases un-official but popular designations for geographical areas. An example of a region that crosses multiple countries is the Alps in Europe. , defaults to None
    :type regions: List[int], optional
    """

    def __init__(
        self,
        address: LazyTranslatedString = None,
        city: int = None,
        coordinates: CoordinatesDto = None,
        country: str = None,
        districts: List[int] = None,
        postal_code: str = None,
        regions: List[int] = None,
    ):
        if address is not None:
            self.address = self._define_object(address, LazyTranslatedString)
        if city is not None:
            self.city = city
        if coordinates is not None:
            self.coordinates = self._define_object(coordinates, CoordinatesDto)
        if country is not None:
            self.country = country
        if districts is not None:
            self.districts = districts
        if postal_code is not None:
            self.postal_code = postal_code
        if regions is not None:
            self.regions = regions



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class Meta(BaseModel):
    """Meta

    :param ruid: ruid, defaults to None
    :type ruid: str, optional
    """

    def __init__(self, ruid: str = None):
        if ruid is not None:
            self.ruid = ruid



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class LazyTranslatedString(BaseModel):
    """Translated accommodation address.

    :param fallback: fallback, defaults to None
    :type fallback: str, optional
    """

    def __init__(self, fallback: str = None):
        if fallback is not None:
            self.fallback = fallback



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .search_output_dto import SearchOutputDto


@JsonMap({})
class ResponseOutputListSearchOutputDto(BaseModel):
    """ResponseOutputListSearchOutputDto

    :param data: data, defaults to None
    :type data: List[SearchOutputDto], optional
    :param request_id: Uniquely identifies the request. Please provide this identifier when contacting support., defaults to None
    :type request_id: str, optional
    :param next_page: Indicates that more results are available. Use this pagination token to retrieve the next page of results (via parameter `page`)., defaults to None
    :type next_page: str, optional
    """

    def __init__(
        self,
        data: List[SearchOutputDto] = None,
        request_id: str = None,
        next_page: str = None,
    ):
        if data is not None:
            self.data = self._define_list(data, SearchOutputDto)
        if request_id is not None:
            self.request_id = request_id
        if next_page is not None:
            self.next_page = next_page



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelThemeTypesOutputDto(BaseModel):
    """HotelThemeTypesOutputDto

    :param theme_id: Unique ID for this theme., defaults to None
    :type theme_id: int, optional
    :param name: Name of the theme., defaults to None
    :type name: str, optional
    """

    def __init__(self, theme_id: int = None, name: str = None):
        if theme_id is not None:
            self.theme_id = theme_id
        if name is not None:
            self.name = name



# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class AllocationInputDto(BaseModel):
    """The exact allocation of guests to rooms.

    :param children: The children ages for this room., defaults to None
    :type children: List[int], optional
    :param number_of_adults: The number of adults for this room.
    :type number_of_adults: int
    """

    def __init__(self, number_of_adults: int, children: List[int] = None):
        if children is not None:
            self.children = children
        self.number_of_adults = number_of_adults



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class BlockAvailabilityInputDtoExtras(Enum):
    """An enumeration representing different categories.

    :cvar ADDON_TYPE: "ADDON_TYPE"
    :vartype ADDON_TYPE: str
    :cvar NET_PRICE: "NET_PRICE"
    :vartype NET_PRICE: str
    :cvar RACK_RATES: "RACK_RATES"
    :vartype RACK_RATES: str
    :cvar MAX_ROOMS_IN_RESERVATION: "MAX_ROOMS_IN_RESERVATION"
    :vartype MAX_ROOMS_IN_RESERVATION: str
    :cvar SMOKING_STATUS: "SMOKING_STATUS"
    :vartype SMOKING_STATUS: str
    :cvar IMPORTANT_INFORMATION: "IMPORTANT_INFORMATION"
    :vartype IMPORTANT_INFORMATION: str
    :cvar ALL_EXTRA_CHARGES: "ALL_EXTRA_CHARGES"
    :vartype ALL_EXTRA_CHARGES: str
    :cvar ADDITIONAL_ROOM_INFO: "ADDITIONAL_ROOM_INFO"
    :vartype ADDITIONAL_ROOM_INFO: str
    :cvar GROUP_RECOMMENDATIONS: "GROUP_RECOMMENDATIONS"
    :vartype GROUP_RECOMMENDATIONS: str
    :cvar ROOM_TYPE_ID: "ROOM_TYPE_ID"
    :vartype ROOM_TYPE_ID: str
    :cvar CC_REQUIRED: "CC_REQUIRED"
    :vartype CC_REQUIRED: str
    :cvar SHOW_CONDITIONAL_CHARGES: "SHOW_CONDITIONAL_CHARGES"
    :vartype SHOW_CONDITIONAL_CHARGES: str
    :cvar POSTCARD_PHOTO: "POSTCARD_PHOTO"
    :vartype POSTCARD_PHOTO: str
    :cvar EXTRA_CHARGES: "EXTRA_CHARGES"
    :vartype EXTRA_CHARGES: str
    :cvar PHOTOS: "PHOTOS"
    :vartype PHOTOS: str
    :cvar INTERNET: "INTERNET"
    :vartype INTERNET: str
    :cvar IF_DOMESTIC_NO_CC: "IF_DOMESTIC_NO_CC"
    :vartype IF_DOMESTIC_NO_CC: str
    :cvar FACILITIES: "FACILITIES"
    :vartype FACILITIES: str
    :cvar EXTRA_BEDS: "EXTRA_BEDS"
    :vartype EXTRA_BEDS: str
    :cvar CANCELLATION_INFO: "CANCELLATION_INFO"
    :vartype CANCELLATION_INFO: str
    :cvar MEALPLANS: "MEALPLANS"
    :vartype MEALPLANS: str
    :cvar DEAL_LASTM: "DEAL_LASTM"
    :vartype DEAL_LASTM: str
    :cvar PAYMENT_TERMS: "PAYMENT_TERMS"
    :vartype PAYMENT_TERMS: str
    :cvar ALL_PRICES: "ALL_PRICES"
    :vartype ALL_PRICES: str
    :cvar BLOCK_PAYMENT_OPTIONS: "BLOCK_PAYMENT_OPTIONS"
    :vartype BLOCK_PAYMENT_OPTIONS: str
    :cvar MAX_CHILDREN_FREE_AGE: "MAX_CHILDREN_FREE_AGE"
    :vartype MAX_CHILDREN_FREE_AGE: str
    :cvar NUMBER_OF_ROOMS_LEFT: "NUMBER_OF_ROOMS_LEFT"
    :vartype NUMBER_OF_ROOMS_LEFT: str
    :cvar MAX_CHILDREN_FREE: "MAX_CHILDREN_FREE"
    :vartype MAX_CHILDREN_FREE: str
    :cvar POLICIES: "POLICIES"
    :vartype POLICIES: str
    :cvar PREPAYMENT_INFO: "PREPAYMENT_INFO"
    :vartype PREPAYMENT_INFO: str
    :cvar DEAL_FLASH: "DEAL_FLASH"
    :vartype DEAL_FLASH: str
    :cvar IF_NO_CC_ALLOWED: "IF_NO_CC_ALLOWED"
    :vartype IF_NO_CC_ALLOWED: str
    :cvar DEAL_SMART: "DEAL_SMART"
    :vartype DEAL_SMART: str
    :cvar ADDONS: "ADDONS"
    :vartype ADDONS: str
    :cvar ADDRESS_REQUIRED: "ADDRESS_REQUIRED"
    :vartype ADDRESS_REQUIRED: str
    """

    ADDON_TYPE = "ADDON_TYPE"
    NET_PRICE = "NET_PRICE"
    RACK_RATES = "RACK_RATES"
    MAX_ROOMS_IN_RESERVATION = "MAX_ROOMS_IN_RESERVATION"
    SMOKING_STATUS = "SMOKING_STATUS"
    IMPORTANT_INFORMATION = "IMPORTANT_INFORMATION"
    ALL_EXTRA_CHARGES = "ALL_EXTRA_CHARGES"
    ADDITIONAL_ROOM_INFO = "ADDITIONAL_ROOM_INFO"
    GROUP_RECOMMENDATIONS = "GROUP_RECOMMENDATIONS"
    ROOM_TYPE_ID = "ROOM_TYPE_ID"
    CC_REQUIRED = "CC_REQUIRED"
    SHOW_CONDITIONAL_CHARGES = "SHOW_CONDITIONAL_CHARGES"
    POSTCARD_PHOTO = "POSTCARD_PHOTO"
    EXTRA_CHARGES = "EXTRA_CHARGES"
    PHOTOS = "PHOTOS"
    INTERNET = "INTERNET"
    IF_DOMESTIC_NO_CC = "IF_DOMESTIC_NO_CC"
    FACILITIES = "FACILITIES"
    EXTRA_BEDS = "EXTRA_BEDS"
    CANCELLATION_INFO = "CANCELLATION_INFO"
    MEALPLANS = "MEALPLANS"
    DEAL_LASTM = "DEAL_LASTM"
    PAYMENT_TERMS = "PAYMENT_TERMS"
    ALL_PRICES = "ALL_PRICES"
    BLOCK_PAYMENT_OPTIONS = "BLOCK_PAYMENT_OPTIONS"
    MAX_CHILDREN_FREE_AGE = "MAX_CHILDREN_FREE_AGE"
    NUMBER_OF_ROOMS_LEFT = "NUMBER_OF_ROOMS_LEFT"
    MAX_CHILDREN_FREE = "MAX_CHILDREN_FREE"
    POLICIES = "POLICIES"
    PREPAYMENT_INFO = "PREPAYMENT_INFO"
    DEAL_FLASH = "DEAL_FLASH"
    IF_NO_CC_ALLOWED = "IF_NO_CC_ALLOWED"
    DEAL_SMART = "DEAL_SMART"
    ADDONS = "ADDONS"
    ADDRESS_REQUIRED = "ADDRESS_REQUIRED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value, BlockAvailabilityInputDtoExtras._member_map_.values()
            )
        )


class BlockAvailabilityInputDtoLanguage(Enum):
    """An enumeration representing different categories.

    :cvar AR: "AR"
    :vartype AR: str
    :cvar BG: "BG"
    :vartype BG: str
    :cvar CA: "CA"
    :vartype CA: str
    :cvar CS: "CS"
    :vartype CS: str
    :cvar DA: "DA"
    :vartype DA: str
    :cvar DE: "DE"
    :vartype DE: str
    :cvar EL: "EL"
    :vartype EL: str
    :cvar EN: "EN"
    :vartype EN: str
    :cvar EN_GB: "EN_GB"
    :vartype EN_GB: str
    :cvar EN_US: "EN_US"
    :vartype EN_US: str
    :cvar ES: "ES"
    :vartype ES: str
    :cvar ES_AR: "ES_AR"
    :vartype ES_AR: str
    :cvar ES_MX: "ES_MX"
    :vartype ES_MX: str
    :cvar ET: "ET"
    :vartype ET: str
    :cvar FI: "FI"
    :vartype FI: str
    :cvar FR: "FR"
    :vartype FR: str
    :cvar HE: "HE"
    :vartype HE: str
    :cvar HI: "HI"
    :vartype HI: str
    :cvar HR: "HR"
    :vartype HR: str
    :cvar HU: "HU"
    :vartype HU: str
    :cvar ID: "ID"
    :vartype ID: str
    :cvar IS: "IS"
    :vartype IS: str
    :cvar IT: "IT"
    :vartype IT: str
    :cvar JA: "JA"
    :vartype JA: str
    :cvar KA: "KA"
    :vartype KA: str
    :cvar KO: "KO"
    :vartype KO: str
    :cvar LT: "LT"
    :vartype LT: str
    :cvar LV: "LV"
    :vartype LV: str
    :cvar MS: "MS"
    :vartype MS: str
    :cvar NL: "NL"
    :vartype NL: str
    :cvar NO: "NO"
    :vartype NO: str
    :cvar PL: "PL"
    :vartype PL: str
    :cvar PT_BR: "PT_BR"
    :vartype PT_BR: str
    :cvar PT_PT: "PT_PT"
    :vartype PT_PT: str
    :cvar RO: "RO"
    :vartype RO: str
    :cvar RU: "RU"
    :vartype RU: str
    :cvar SK: "SK"
    :vartype SK: str
    :cvar SL: "SL"
    :vartype SL: str
    :cvar SR: "SR"
    :vartype SR: str
    :cvar SV: "SV"
    :vartype SV: str
    :cvar TH: "TH"
    :vartype TH: str
    :cvar TL: "TL"
    :vartype TL: str
    :cvar TR: "TR"
    :vartype TR: str
    :cvar UK: "UK"
    :vartype UK: str
    :cvar VI: "VI"
    :vartype VI: str
    :cvar ZH_CN: "ZH_CN"
    :vartype ZH_CN: str
    :cvar ZH_TW: "ZH_TW"
    :vartype ZH_TW: str
    """

    AR = "AR"
    BG = "BG"
    CA = "CA"
    CS = "CS"
    DA = "DA"
    DE = "DE"
    EL = "EL"
    EN = "EN"
    EN_GB = "EN_GB"
    EN_US = "EN_US"
    ES = "ES"
    ES_AR = "ES_AR"
    ES_MX = "ES_MX"
    ET = "ET"
    FI = "FI"
    FR = "FR"
    HE = "HE"
    HI = "HI"
    HR = "HR"
    HU = "HU"
    ID = "ID"
    IS = "IS"
    IT = "IT"
    JA = "JA"
    KA = "KA"
    KO = "KO"
    LT = "LT"
    LV = "LV"
    MS = "MS"
    NL = "NL"
    NO = "NO"
    PL = "PL"
    PT_BR = "PT_BR"
    PT_PT = "PT_PT"
    RO = "RO"
    RU = "RU"
    SK = "SK"
    SL = "SL"
    SR = "SR"
    SV = "SV"
    TH = "TH"
    TL = "TL"
    TR = "TR"
    UK = "UK"
    VI = "VI"
    ZH_CN = "ZH_CN"
    ZH_TW = "ZH_TW"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                BlockAvailabilityInputDtoLanguage._member_map_.values(),
            )
        )


class BlockAvailabilityInputDtoUserPlatform(Enum):
    """An enumeration representing different categories.

    :cvar ANDROID: "ANDROID"
    :vartype ANDROID: str
    :cvar DESKTOP: "DESKTOP"
    :vartype DESKTOP: str
    :cvar IOS: "IOS"
    :vartype IOS: str
    :cvar MOBILE: "MOBILE"
    :vartype MOBILE: str
    :cvar TABLET: "TABLET"
    :vartype TABLET: str
    """

    ANDROID = "ANDROID"
    DESKTOP = "DESKTOP"
    IOS = "IOS"
    MOBILE = "MOBILE"
    TABLET = "TABLET"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                BlockAvailabilityInputDtoUserPlatform._member_map_.values(),
            )
        )


@JsonMap({})
class BlockAvailabilityInputDto(BaseModel):
    """BlockAvailabilityInputDto

    :param hotel_ids: Hotel ID(s) to check availability for.
    :type hotel_ids: List[int]
    :param checkin: The arrival date.
    :type checkin: str
    :param checkout: The departure date. Must be later than {checkin}.
    :type checkout: str
    :param guest_cc: Guest country code. Used to accurately display the best prices and price details for people from that country.
    :type guest_cc: str
    :param currency: Returns the prices in this currency, in addition to the hotel currency., defaults to None
    :type currency: str, optional
    :param extras: The extra items for this request. See the documentation for more details about each extra., defaults to None
    :type extras: List[BlockAvailabilityInputDtoExtras], optional
    :param affiliate_id: Application affiliate id, defaults to None
    :type affiliate_id: str, optional
    :param block_ids: Return only availability hits with these particular block IDs, defaults to None
    :type block_ids: List[str], optional
    :param guest_ip: Guest IP address for determining guest country and showing the best price for that user and obeying laws regarding the display of taxes and fees. , defaults to None
    :type guest_ip: str, optional
    :param guest_qty: Number of guests for which blocks will be found. The total number of guests is used for calculating city tax charges. It is specified as an array of guest numbers. If you use this parameter and make bookings through the API, you should also set the exact same value in the guest_quantities parameter for the processBooking call, otherwise per-person included charges may result in pricing problems, causing the booking to fail. NOTE: After version 2.6 either this or `room1` needs to be provided. , defaults to None
    :type guest_qty: List[int], optional
    :param language: Specify the language for: block_id, policies, room texts and hotel descriptions. Note: not all text is translated in all languages. Please check the "Possible Values" section of the documentation for the accepted language codes. , defaults to None
    :type language: BlockAvailabilityInputDtoLanguage, optional
    :param num_rooms: Takes a number of rooms to put guests into, defaults to None
    :type num_rooms: int, optional
    :param room1: Which guests to put in which rooms. Syntax: comma-separated list, `A` for each adult, a number in the range 0..17 for each child. , defaults to None
    :type room1: List[str], optional
    :param user_platform: The user's platform., defaults to None
    :type user_platform: BlockAvailabilityInputDtoUserPlatform, optional
    """

    def __init__(
        self,
        hotel_ids: List[int],
        checkin: str,
        checkout: str,
        guest_cc: str,
        currency: str = None,
        extras: List[BlockAvailabilityInputDtoExtras] = None,
        affiliate_id: str = None,
        block_ids: List[str] = None,
        guest_ip: str = None,
        guest_qty: List[int] = None,
        language: BlockAvailabilityInputDtoLanguage = None,
        num_rooms: int = None,
        room1: List[str] = None,
        user_platform: BlockAvailabilityInputDtoUserPlatform = None,
    ):
        self.hotel_ids = hotel_ids
        self.checkin = checkin
        self.checkout = checkout
        self.guest_cc = guest_cc
        if currency is not None:
            self.currency = currency
        if extras is not None:
            self.extras = self._define_list(extras, BlockAvailabilityInputDtoExtras)
        if affiliate_id is not None:
            self.affiliate_id = affiliate_id
        if block_ids is not None:
            self.block_ids = block_ids
        if guest_ip is not None:
            self.guest_ip = guest_ip
        if guest_qty is not None:
            self.guest_qty = guest_qty
        if language is not None:
            self.language = self._enum_matching(
                language, BlockAvailabilityInputDtoLanguage.list(), "language"
            )
        if num_rooms is not None:
            self.num_rooms = num_rooms
        if room1 is not None:
            self.room1 = room1
        if user_platform is not None:
            self.user_platform = self._enum_matching(
                user_platform,
                BlockAvailabilityInputDtoUserPlatform.list(),
                "user_platform",
            )



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class NumberOfRoomsDto(BaseModel):
    """Total rooms available.

    :param bathrooms: bathrooms, defaults to None
    :type bathrooms: int, optional
    :param bedrooms: bedrooms, defaults to None
    :type bedrooms: int, optional
    :param living_rooms: living_rooms, defaults to None
    :type living_rooms: int, optional
    """

    def __init__(
        self, bathrooms: int = None, bedrooms: int = None, living_rooms: int = None
    ):
        if bathrooms is not None:
            self.bathrooms = bathrooms
        if bedrooms is not None:
            self.bedrooms = bedrooms
        if living_rooms is not None:
            self.living_rooms = living_rooms



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class RoomOccupancyDto(BaseModel):
    """RoomOccupancyDto

    :param allow_cribs_and_extra_beds: allow_cribs_and_extra_beds, defaults to None
    :type allow_cribs_and_extra_beds: bool, optional
    :param max_adults: max_adults, defaults to None
    :type max_adults: int, optional
    :param max_children: max_children, defaults to None
    :type max_children: int, optional
    :param max_cribs: max_cribs, defaults to None
    :type max_cribs: int, optional
    :param max_extra_beds: max_extra_beds, defaults to None
    :type max_extra_beds: int, optional
    :param max_occupancy: max_occupancy, defaults to None
    :type max_occupancy: int, optional
    """

    def __init__(
        self,
        allow_cribs_and_extra_beds: bool = None,
        max_adults: int = None,
        max_children: int = None,
        max_cribs: int = None,
        max_extra_beds: int = None,
        max_occupancy: int = None,
    ):
        if allow_cribs_and_extra_beds is not None:
            self.allow_cribs_and_extra_beds = allow_cribs_and_extra_beds
        if max_adults is not None:
            self.max_adults = max_adults
        if max_children is not None:
            self.max_children = max_children
        if max_cribs is not None:
            self.max_cribs = max_cribs
        if max_extra_beds is not None:
            self.max_extra_beds = max_extra_beds
        if max_occupancy is not None:
            self.max_occupancy = max_occupancy



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class PhotoUrlDto(BaseModel):
    """PhotoUrlDto

    :param large: URL of the photo image with a maximum width of 1280 pixels., defaults to None
    :type large: str, optional
    :param standard: URL of the photo image with a maximum width of 500 pixels., defaults to None
    :type standard: str, optional
    :param thumbnail: URL of the photo thumbnail image with dimensions 100x100 pixels., defaults to None
    :type thumbnail: str, optional
    :param thumbnail_large: URL of the photo thumbnail image with dimensions 300x300 pixels., defaults to None
    :type thumbnail_large: str, optional
    """

    def __init__(
        self,
        large: str = None,
        standard: str = None,
        thumbnail: str = None,
        thumbnail_large: str = None,
    ):
        if large is not None:
            self.large = large
        if standard is not None:
            self.standard = standard
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if thumbnail_large is not None:
            self.thumbnail_large = thumbnail_large



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class HotelAvailabilityInputDtoUserPlatform(Enum):
    """An enumeration representing different categories.

    :cvar ANDROID: "ANDROID"
    :vartype ANDROID: str
    :cvar DESKTOP: "DESKTOP"
    :vartype DESKTOP: str
    :cvar IOS: "IOS"
    :vartype IOS: str
    :cvar MOBILE: "MOBILE"
    :vartype MOBILE: str
    :cvar TABLET: "TABLET"
    :vartype TABLET: str
    """

    ANDROID = "ANDROID"
    DESKTOP = "DESKTOP"
    IOS = "IOS"
    MOBILE = "MOBILE"
    TABLET = "TABLET"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                HotelAvailabilityInputDtoUserPlatform._member_map_.values(),
            )
        )


@JsonMap({})
class HotelAvailabilityInputDto(BaseModel):
    """HotelAvailabilityInputDto

    :param checkin: The arrival date.
    :type checkin: str
    :param checkout: The departure date. Must be later than {checkin}. Must be between 1 and 30 days after {checkin}.
    :type checkout: str
    :param hotel_ids: Limit the result list to up to 1000 specified hotels where they have availability for the specified guests and dates., defaults to None
    :type hotel_ids: List[int], optional
    :param currency: Returns the price in this currency, defaults to None
    :type currency: str, optional
    :param guest_country: Guest country code. Used to accurately display the best prices and price details for people from that country.
    :type guest_country: str
    :param no_rooms: The only group will be split in the given number of rooms automatically
    :type no_rooms: int
    :param user_platform: The user's platform., defaults to None
    :type user_platform: HotelAvailabilityInputDtoUserPlatform, optional
    :param rows: The maximum number of results to return., defaults to None
    :type rows: int, optional
    :param page: Pagination token used to retrieve the next page of results. Obtained from `next_page`., defaults to None
    :type page: str, optional
    """

    def __init__(
        self,
        checkin: str,
        checkout: str,
        guest_country: str,
        no_rooms: int,
        hotel_ids: List[int] = None,
        currency: str = None,
        user_platform: HotelAvailabilityInputDtoUserPlatform = None,
        rows: int = None,
        page: str = None,
    ):
        self.checkin = checkin
        self.checkout = checkout
        if hotel_ids is not None:
            self.hotel_ids = hotel_ids
        if currency is not None:
            self.currency = currency
        self.guest_country = guest_country
        self.no_rooms = no_rooms
        if user_platform is not None:
            self.user_platform = self._enum_matching(
                user_platform,
                HotelAvailabilityInputDtoUserPlatform.list(),
                "user_platform",
            )
        if rows is not None:
            self.rows = rows
        if page is not None:
            self.page = page



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class CribsAndExtraBedsDto(BaseModel):
    """Lists room options regarding adding cribs and/or extra beds.

    :param are_allowed: Flags if cots and extra beds can be placed together in the room. `true` allows both up to their maximum limits. `false` requires exclusive choice of either cots or extra beds. , defaults to None
    :type are_allowed: bool, optional
    :param maximum_number_of_cribs: Maximum number of cribs that can be added., defaults to None
    :type maximum_number_of_cribs: int, optional
    :param maximum_number_of_extra_beds: Maximum number of extra beds that can be added., defaults to None
    :type maximum_number_of_extra_beds: int, optional
    """

    def __init__(
        self,
        are_allowed: bool = None,
        maximum_number_of_cribs: int = None,
        maximum_number_of_extra_beds: int = None,
    ):
        if are_allowed is not None:
            self.are_allowed = are_allowed
        if maximum_number_of_cribs is not None:
            self.maximum_number_of_cribs = maximum_number_of_cribs
        if maximum_number_of_extra_beds is not None:
            self.maximum_number_of_extra_beds = maximum_number_of_extra_beds



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ExtraChargesDtoDouble(BaseModel):
    """The charge breakdown. Includes taxes and fees.

    :param excluded: Charges not included in 'book'., defaults to None
    :type excluded: float, optional
    :param included: Charges included in 'book'., defaults to None
    :type included: float, optional
    :param conditional: conditional, defaults to None
    :type conditional: float, optional
    """

    def __init__(
        self, excluded: float = None, included: float = None, conditional: float = None
    ):
        if excluded is not None:
            self.excluded = excluded
        if included is not None:
            self.included = included
        if conditional is not None:
            self.conditional = conditional



# This file was generated by liblab | https://liblab.com/

from .search_input_dto import SearchInputDto
from .response_output_list_search_output_dto import ResponseOutputListSearchOutputDto
from .search_accept import SearchAccept
from .details_input_dto import DetailsInputDto
from .response_output_list_details_output_dto import ResponseOutputListDetailsOutputDto
from .post_details_accept import PostDetailsAccept
from .constant_input_dto import ConstantInputDto
from .response_output_constants_output_dto import ResponseOutputConstantsOutputDto
from .get_accommodation_constants_accept import GetAccommodationConstantsAccept
from .response_output_v2_review_scores_output_dto import (
    ResponseOutputV2ReviewScoresOutputDto,
)
from .review_scores_input_dto import ReviewScoresInputDto
from .get_hotels_review_scores_accept import GetHotelsReviewScoresAccept
from .response_output_v2_hotels_output_dto import ResponseOutputV2HotelsOutputDto
from .hotels_input_dto import HotelsInputDto
from .get_hotels_accept import GetHotelsAccept
from .response_output_v2_hotel_types_output_dto import (
    ResponseOutputV2HotelTypesOutputDto,
)
from .hotel_type_input_dto import HotelTypeInputDto
from .get_hotel_types_accept import GetHotelTypesAccept
from .response_output_v2_hotel_theme_types_output_dto import (
    ResponseOutputV2HotelThemeTypesOutputDto,
)
from .hotel_theme_type_input_dto import HotelThemeTypeInputDto
from .get_hotel_theme_types_accept import GetHotelThemeTypesAccept
from .response_output_v2_hotel_facility_type_output_dto import (
    ResponseOutputV2HotelFacilityTypeOutputDto,
)
from .hotel_facility_input_dto import HotelFacilityInputDto
from .get_room_facility_types_accept import GetRoomFacilityTypesAccept
from .response_output_v2_hotel_availability_output_dto import (
    ResponseOutputV2HotelAvailabilityOutputDto,
)
from .hotel_availability_input_dto import HotelAvailabilityInputDto
from .get_hotel_availability_accept import GetHotelAvailabilityAccept
from .response_output_v2_block_availability_output_dto import (
    ResponseOutputV2BlockAvailabilityOutputDto,
)
from .block_availability_input_dto import BlockAvailabilityInputDto
from .get_block_availability_accept import GetBlockAvailabilityAccept
from .booker_input_dto import BookerInputDto
from .guests_input_dto import GuestsInputDto
from .coordinates import Coordinates
from .allocation_input_dto import AllocationInputDto
from .search_output_dto import SearchOutputDto
from .price_data_dto_double import PriceDataDtoDouble
from .product_dto import ProductDto
from .extra_charges_dto_double import ExtraChargesDtoDouble
from .policies_dto import PoliciesDto
from .price_data_dto_list_charge_dto import PriceDataDtoListChargeDto
from .deal_dto import DealDto
from .cancellation_dto import CancellationDto
from .meal_plan_dto import MealPlanDto
from .payment_dto import PaymentDto
from .extra_charges_dto_list_charge_dto import ExtraChargesDtoListChargeDto
from .charge_dto import ChargeDto
from .details_output_dto import DetailsOutputDto
from .translated_string import TranslatedString
from .checkin_checkout_times_dto import CheckinCheckoutTimesDto
from .contacts_dto import ContactsDto
from .facility_dto import FacilityDto
from .description_dto import DescriptionDto
from .key_collection_information_dto import KeyCollectionInformationDto
from .location_dto import LocationDto
from .photo_dto import PhotoDto
from .program_settings_dto import ProgramSettingsDto
from .rating_dto import RatingDto
from .room_dto import RoomDto
from .local_time import LocalTime
from .contact_dto import ContactDto
from .translation_information import TranslationInformation
from .truncated_string import TruncatedString
from .alternative_key_location_dto import AlternativeKeyLocationDto
from .lazy_translated_string import LazyTranslatedString
from .coordinates_dto import CoordinatesDto
from .photo_url_dto import PhotoUrlDto
from .bed_option_dto import BedOptionDto
from .cribs_and_extra_beds_dto import CribsAndExtraBedsDto
from .room_maximum_occupancy_dto import RoomMaximumOccupancyDto
from .number_of_rooms_dto import NumberOfRoomsDto
from .bed_configuration_dto import BedConfigurationDto
from .bed_dto import BedDto
from .meta import Meta
from .review_scores_output_dto import ReviewScoresOutputDto
from .score_breakdown import ScoreBreakdown
from .score_distribution import ScoreDistribution
from .question_dto import QuestionDto
from .hotels_output_dto import HotelsOutputDto
from .hotel_data_dto import HotelDataDto
from .room_data_dto import RoomDataDto
from .hotel_photo_dto import HotelPhotoDto
from .room_info_dto import RoomInfoDto
from .bedroom_dto import BedroomDto
from .room_occupancy_dto import RoomOccupancyDto
from .room_size_dto import RoomSizeDto
from .hotel_types_output_dto import HotelTypesOutputDto
from .translation_dto import TranslationDto
from .hotel_theme_types_output_dto import HotelThemeTypesOutputDto
from .hotel_facility_type_output_dto import HotelFacilityTypeOutputDto
from .hotel_availability_output_dto import HotelAvailabilityOutputDto
from .block_availability_output_dto import BlockAvailabilityOutputDto
from .block_output_dto import BlockOutputDto



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .alternative_key_location_dto import AlternativeKeyLocationDto


@JsonMap({})
class KeyCollectionInformationDto(BaseModel):
    """KeyCollectionInformationDto

    :param alternate_location: Alternate location to collect the key of this accommodation property. This is returned if the key to access the property is in another location. , defaults to None
    :type alternate_location: AlternativeKeyLocationDto, optional
    :param checkin_method: An enumeration that describes the conditions for the checkin process and for collecting the key to access the property. This is typically relevant for non-hotel accommodations (like houses or apartments) without a 24 hours front-desk. , defaults to None
    :type checkin_method: str, optional
    :param key_location: Location of the key to access this accommodation property., defaults to None
    :type key_location: str, optional
    """

    def __init__(
        self,
        alternate_location: AlternativeKeyLocationDto = None,
        checkin_method: str = None,
        key_location: str = None,
    ):
        if alternate_location is not None:
            self.alternate_location = self._define_object(
                alternate_location, AlternativeKeyLocationDto
            )
        if checkin_method is not None:
            self.checkin_method = checkin_method
        if key_location is not None:
            self.key_location = key_location



# This file was generated by liblab | https://liblab.com/

from enum import Enum


class GetAccommodationConstantsAccept(Enum):
    """An enumeration representing different categories.

    :cvar APPLICATION_JSON: "application/json"
    :vartype APPLICATION_JSON: str
    """

    APPLICATION_JSON = "application/json"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value, GetAccommodationConstantsAccept._member_map_.values()
            )
        )



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ScoreDistribution(BaseModel):
    """A breakdown of all review scores into buckets 1 - 10.

    :param count: Total number of reviews in this bucket., defaults to None
    :type count: int, optional
    :param percent: Percent of score distribution that went into this bucket., defaults to None
    :type percent: float, optional
    :param score: The bucket's review score value (1 - 10)., defaults to None
    :type score: int, optional
    """

    def __init__(self, count: int = None, percent: float = None, score: int = None):
        if count is not None:
            self.count = count
        if percent is not None:
            self.percent = percent
        if score is not None:
            self.score = score



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .score_breakdown import ScoreBreakdown
from .score_distribution import ScoreDistribution


@JsonMap({})
class ReviewScoresOutputDto(BaseModel):
    """ReviewScoresOutputDto

    :param hotel_id: Id of the hotel., defaults to None
    :type hotel_id: int, optional
    :param hotel_url: URL of the hotel's page on Booking.com., defaults to None
    :type hotel_url: str, optional
    :param score_breakdown: A breakdown of scores per reviewer type and review question., defaults to None
    :type score_breakdown: List[ScoreBreakdown], optional
    :param score_distribution: A breakdown of all review scores into buckets 1 - 10., defaults to None
    :type score_distribution: List[ScoreDistribution], optional
    """

    def __init__(
        self,
        hotel_id: int = None,
        hotel_url: str = None,
        score_breakdown: List[ScoreBreakdown] = None,
        score_distribution: List[ScoreDistribution] = None,
    ):
        if hotel_id is not None:
            self.hotel_id = hotel_id
        if hotel_url is not None:
            self.hotel_url = hotel_url
        if score_breakdown is not None:
            self.score_breakdown = self._define_list(score_breakdown, ScoreBreakdown)
        if score_distribution is not None:
            self.score_distribution = self._define_list(
                score_distribution, ScoreDistribution
            )



# This file was generated by liblab | https://liblab.com/

from .services.demand_api_v3_compatible import DemandApiV3CompatibleService
from .services.demand_api_v2_compatible import DemandApiV2CompatibleService
from .net.environment import Environment


class Booking:
    def __init__(
        self,
        access_token: str = None,
        api_key: str = None,
        api_key_header: str = "X-Affiliate-id",
        base_url: str = Environment.DEFAULT.value,
    ):
        """
        Initializes Booking the SDK class.
        """
        self.demand_api_v3_compatible = DemandApiV3CompatibleService(base_url=base_url)
        self.demand_api_v2_compatible = DemandApiV2CompatibleService(base_url=base_url)
        self.set_access_token(access_token)
        self.set_api_key(api_key, api_key_header)

    def set_base_url(self, base_url):
        """
        Sets the base URL for the entire SDK.
        """
        self.demand_api_v3_compatible.set_base_url(base_url)
        self.demand_api_v2_compatible.set_base_url(base_url)

        return self

    def set_access_token(self, access_token: str):
        """
        Sets the access token for the entire SDK.
        """
        self.demand_api_v3_compatible.set_access_token(access_token)
        self.demand_api_v2_compatible.set_access_token(access_token)

        return self

    def set_api_key(self, api_key: str, api_key_header="X-Affiliate-id"):
        """
        Sets the api key and the api key header for the entire SDK.
        """
        self.demand_api_v3_compatible.set_api_key(api_key, api_key_header)
        self.demand_api_v2_compatible.set_api_key(api_key, api_key_header)

        return self


# c029837e0e474b76bc487506e8799df5e3335891efe4fb02bda7a1441840310c



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class Coordinates(BaseModel):
    """Limit the result list to the specified coordinates.

    :param latitude: Specify a latitude (as well as a longitude and radius) to do searches around a specific location.
    :type latitude: float
    :param longitude: Specify a longitude (as well as a latitude and radius) to do searches around a specific location.
    :type longitude: float
    :param radius: The radius is km to search around the specified latitude and longitude.
    :type radius: float
    """

    def __init__(self, latitude: float, longitude: float, radius: float):
        self.latitude = latitude
        self.longitude = longitude
        self.radius = radius



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ContactDto(BaseModel):
    """Contact information of the accommodation. It can be `null` if the data is missing.

    :param email: Email address of the accommodation. It can be `null` if the data is missing., defaults to None
    :type email: dict, optional
    :param telephone: Telephone number of the accommodation. It can be `null` if the data is missing., defaults to None
    :type telephone: dict, optional
    """

    def __init__(self, email: dict = None, telephone: dict = None):
        if email is not None:
            self.email = email
        if telephone is not None:
            self.telephone = telephone



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .policies_dto import PoliciesDto
from .price_data_dto_list_charge_dto import PriceDataDtoListChargeDto
from .deal_dto import DealDto


@JsonMap({"id_": "id"})
class ProductDto(BaseModel):
    """ProductDto

    :param id_: Unique ID of the product., defaults to None
    :type id_: str, optional
    :param policies: The policies for this product., defaults to None
    :type policies: PoliciesDto, optional
    :param price: The price components of this product or selection of products. 'base' and 'extra_charges' are returned only when explicitly requested (via 'extras=extra_charges'). , defaults to None
    :type price: PriceDataDtoListChargeDto, optional
    :param deal: This specifies the deal tagging for the product., defaults to None
    :type deal: DealDto, optional
    """

    def __init__(
        self,
        id_: str = None,
        policies: PoliciesDto = None,
        price: PriceDataDtoListChargeDto = None,
        deal: DealDto = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if policies is not None:
            self.policies = self._define_object(policies, PoliciesDto)
        if price is not None:
            self.price = self._define_object(price, PriceDataDtoListChargeDto)
        if deal is not None:
            self.deal = self._define_object(deal, DealDto)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class DetailsInputDtoExtras(Enum):
    """An enumeration representing different categories.

    :cvar DESCRIPTION: "DESCRIPTION"
    :vartype DESCRIPTION: str
    :cvar FACILITIES: "FACILITIES"
    :vartype FACILITIES: str
    :cvar PAYMENT: "PAYMENT"
    :vartype PAYMENT: str
    :cvar PHOTOS: "PHOTOS"
    :vartype PHOTOS: str
    :cvar POLICIES: "POLICIES"
    :vartype POLICIES: str
    :cvar ROOMS: "ROOMS"
    :vartype ROOMS: str
    """

    DESCRIPTION = "DESCRIPTION"
    FACILITIES = "FACILITIES"
    PAYMENT = "PAYMENT"
    PHOTOS = "PHOTOS"
    POLICIES = "POLICIES"
    ROOMS = "ROOMS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, DetailsInputDtoExtras._member_map_.values()))


class DetailsInputDtoLanguages(Enum):
    """An enumeration representing different categories.

    :cvar AR: "AR"
    :vartype AR: str
    :cvar BG: "BG"
    :vartype BG: str
    :cvar CA: "CA"
    :vartype CA: str
    :cvar CS: "CS"
    :vartype CS: str
    :cvar DA: "DA"
    :vartype DA: str
    :cvar DE: "DE"
    :vartype DE: str
    :cvar EL: "EL"
    :vartype EL: str
    :cvar EN: "EN"
    :vartype EN: str
    :cvar EN_GB: "EN_GB"
    :vartype EN_GB: str
    :cvar EN_US: "EN_US"
    :vartype EN_US: str
    :cvar ES: "ES"
    :vartype ES: str
    :cvar ES_AR: "ES_AR"
    :vartype ES_AR: str
    :cvar ES_MX: "ES_MX"
    :vartype ES_MX: str
    :cvar ET: "ET"
    :vartype ET: str
    :cvar FI: "FI"
    :vartype FI: str
    :cvar FR: "FR"
    :vartype FR: str
    :cvar HE: "HE"
    :vartype HE: str
    :cvar HI: "HI"
    :vartype HI: str
    :cvar HR: "HR"
    :vartype HR: str
    :cvar HU: "HU"
    :vartype HU: str
    :cvar ID: "ID"
    :vartype ID: str
    :cvar IS: "IS"
    :vartype IS: str
    :cvar IT: "IT"
    :vartype IT: str
    :cvar JA: "JA"
    :vartype JA: str
    :cvar KA: "KA"
    :vartype KA: str
    :cvar KO: "KO"
    :vartype KO: str
    :cvar LT: "LT"
    :vartype LT: str
    :cvar LV: "LV"
    :vartype LV: str
    :cvar MS: "MS"
    :vartype MS: str
    :cvar NL: "NL"
    :vartype NL: str
    :cvar NO: "NO"
    :vartype NO: str
    :cvar PL: "PL"
    :vartype PL: str
    :cvar PT_BR: "PT_BR"
    :vartype PT_BR: str
    :cvar PT_PT: "PT_PT"
    :vartype PT_PT: str
    :cvar RO: "RO"
    :vartype RO: str
    :cvar RU: "RU"
    :vartype RU: str
    :cvar SK: "SK"
    :vartype SK: str
    :cvar SL: "SL"
    :vartype SL: str
    :cvar SR: "SR"
    :vartype SR: str
    :cvar SV: "SV"
    :vartype SV: str
    :cvar TH: "TH"
    :vartype TH: str
    :cvar TL: "TL"
    :vartype TL: str
    :cvar TR: "TR"
    :vartype TR: str
    :cvar UK: "UK"
    :vartype UK: str
    :cvar VI: "VI"
    :vartype VI: str
    :cvar ZH_CN: "ZH_CN"
    :vartype ZH_CN: str
    :cvar ZH_TW: "ZH_TW"
    :vartype ZH_TW: str
    """

    AR = "AR"
    BG = "BG"
    CA = "CA"
    CS = "CS"
    DA = "DA"
    DE = "DE"
    EL = "EL"
    EN = "EN"
    EN_GB = "EN_GB"
    EN_US = "EN_US"
    ES = "ES"
    ES_AR = "ES_AR"
    ES_MX = "ES_MX"
    ET = "ET"
    FI = "FI"
    FR = "FR"
    HE = "HE"
    HI = "HI"
    HR = "HR"
    HU = "HU"
    ID = "ID"
    IS = "IS"
    IT = "IT"
    JA = "JA"
    KA = "KA"
    KO = "KO"
    LT = "LT"
    LV = "LV"
    MS = "MS"
    NL = "NL"
    NO = "NO"
    PL = "PL"
    PT_BR = "PT_BR"
    PT_PT = "PT_PT"
    RO = "RO"
    RU = "RU"
    SK = "SK"
    SL = "SL"
    SR = "SR"
    SV = "SV"
    TH = "TH"
    TL = "TL"
    TR = "TR"
    UK = "UK"
    VI = "VI"
    ZH_CN = "ZH_CN"
    ZH_TW = "ZH_TW"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, DetailsInputDtoLanguages._member_map_.values())
        )


@JsonMap({})
class DetailsInputDto(BaseModel):
    """DetailsInputDto

    :param accommodations: A signed integer number that uniquely identifies an accommodation property., defaults to None
    :type accommodations: List[int], optional
    :param accommodation_facilities: A signed integer number that uniquely identifies an accommodation property facility. Examples of facilities are: Parking, Restaurant, Room service etc. , defaults to None
    :type accommodation_facilities: List[int], optional
    :param accommodation_types: A signed integer number that uniquely identifies an accommodation property type. Examples of accommodation types are: Apartment, Hostel, Hotel etc., defaults to None
    :type accommodation_types: List[int], optional
    :param airport: A three-letter code that uniquely identifies an airport as defined by the International Air Transport Association (IATA)., defaults to None
    :type airport: str, optional
    :param brands: A signed integer number that uniquely identifies an accommodation brand. Examples of brands are: Radisson Blu, WestCord Hotels, Westin etc. , defaults to None
    :type brands: List[int], optional
    :param city: A signed integer number that uniquely identifies a city., defaults to None
    :type city: int, optional
    :param country: A two-letter code that uniquely identifies a country. This code is defined by the ISO 3166-1 alpha-2 standard (ISO2) as described here: https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2. , defaults to None
    :type country: str, optional
    :param region: A signed integer number that uniquely identifies a geographical region. Regions usually define official administrative areas within a country, but may also include multiple countries and in some cases un-official but popular designations for geographical areas. An example of a region that crosses multiple countries is the Alps in Europe. , defaults to None
    :type region: int, optional
    :param extras: Input parameter to request for additional information about the accommodation property. It should be passed as a JSON array with one or more items. , defaults to None
    :type extras: List[DetailsInputDtoExtras], optional
    :param languages: An IETF language tag code that uniquely identifies a supported human language or dialect as described here: https://en.wikipedia.org/wiki/IETF_language_tag. Note that in in demand-api-v3-compatible the whole tag is always lowercase. Examples: "nl" for Dutch/Nederlands or "en-us" for English (US). , defaults to None
    :type languages: List[DetailsInputDtoLanguages], optional
    :param rows: The maximum number of results to return., defaults to None
    :type rows: int, optional
    :param page: Pagination token used to retrieve the next page of results. Obtained from `next_page`., defaults to None
    :type page: str, optional
    """

    def __init__(
        self,
        accommodations: List[int] = None,
        accommodation_facilities: List[int] = None,
        accommodation_types: List[int] = None,
        airport: str = None,
        brands: List[int] = None,
        city: int = None,
        country: str = None,
        region: int = None,
        extras: List[DetailsInputDtoExtras] = None,
        languages: List[DetailsInputDtoLanguages] = None,
        rows: int = None,
        page: str = None,
    ):
        if accommodations is not None:
            self.accommodations = accommodations
        if accommodation_facilities is not None:
            self.accommodation_facilities = accommodation_facilities
        if accommodation_types is not None:
            self.accommodation_types = accommodation_types
        if airport is not None:
            self.airport = self._pattern_matching(airport, "^[A-Z]{3}$", "airport")
        if brands is not None:
            self.brands = brands
        if city is not None:
            self.city = city
        if country is not None:
            self.country = self._pattern_matching(country, "^[a-z]{2}$", "country")
        if region is not None:
            self.region = region
        if extras is not None:
            self.extras = self._define_list(extras, DetailsInputDtoExtras)
        if languages is not None:
            self.languages = self._define_list(languages, DetailsInputDtoLanguages)
        if rows is not None:
            self.rows = rows
        if page is not None:
            self.page = page



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .translated_string import TranslatedString
from .bed_option_dto import BedOptionDto
from .cribs_and_extra_beds_dto import CribsAndExtraBedsDto
from .room_maximum_occupancy_dto import RoomMaximumOccupancyDto
from .number_of_rooms_dto import NumberOfRoomsDto


class RoomDtoAttributes(Enum):
    """An enumeration representing different categories.

    :cvar NON_SMOKING: "NON_SMOKING"
    :vartype NON_SMOKING: str
    :cvar WORK_FRIENDLY: "WORK_FRIENDLY"
    :vartype WORK_FRIENDLY: str
    """

    NON_SMOKING = "NON_SMOKING"
    WORK_FRIENDLY = "WORK_FRIENDLY"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, RoomDtoAttributes._member_map_.values()))


@JsonMap({"id_": "id"})
class RoomDto(BaseModel):
    """The list of room types available at this property. Requires `{"extras":["rooms"]}`.

    :param id_: A signed integer number that uniquely identifies an accommodation property room., defaults to None
    :type id_: int, optional
    :param name: Translated description of this room. The maximum number of characters returned may be limited by contract., defaults to None
    :type name: TranslatedString, optional
    :param attributes: Lists a set of attribute qualifiers for this room. Will not be returned if no relevant attributes are applicable., defaults to None
    :type attributes: List[RoomDtoAttributes], optional
    :param bed_options: Lists all possible bedding options for this room or apartment., defaults to None
    :type bed_options: List[BedOptionDto], optional
    :param cribs_and_extra_beds: Lists room options regarding adding cribs and/or extra beds., defaults to None
    :type cribs_and_extra_beds: CribsAndExtraBedsDto, optional
    :param description: Translated description of this room. The maximum number of characters returned may be limited by contract., defaults to None
    :type description: TranslatedString, optional
    :param facilities: A signed integer number that uniquely identifies an accommodation property room facility. Examples of facilities are: Coffee/Tea maker, TV, Airconditioning, etc., defaults to None
    :type facilities: List[int], optional
    :param maximum_occupancy: Occupancy limits and options., defaults to None
    :type maximum_occupancy: RoomMaximumOccupancyDto, optional
    :param number_of_rooms: Total rooms available., defaults to None
    :type number_of_rooms: NumberOfRoomsDto, optional
    :param room_type: A signed integer number that uniquely identifies an accommodation property room type. Example of room types are: Suite, Apartment, Twin/Double etc. , defaults to None
    :type room_type: int, optional
    :param size: The room area in square meters., defaults to None
    :type size: int, optional
    """

    def __init__(
        self,
        id_: int = None,
        name: TranslatedString = None,
        attributes: List[RoomDtoAttributes] = None,
        bed_options: List[BedOptionDto] = None,
        cribs_and_extra_beds: CribsAndExtraBedsDto = None,
        description: TranslatedString = None,
        facilities: List[int] = None,
        maximum_occupancy: RoomMaximumOccupancyDto = None,
        number_of_rooms: NumberOfRoomsDto = None,
        room_type: int = None,
        size: int = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if name is not None:
            self.name = self._define_object(name, TranslatedString)
        if attributes is not None:
            self.attributes = self._define_list(attributes, RoomDtoAttributes)
        if bed_options is not None:
            self.bed_options = self._define_list(bed_options, BedOptionDto)
        if cribs_and_extra_beds is not None:
            self.cribs_and_extra_beds = self._define_object(
                cribs_and_extra_beds, CribsAndExtraBedsDto
            )
        if description is not None:
            self.description = self._define_object(description, TranslatedString)
        if facilities is not None:
            self.facilities = facilities
        if maximum_occupancy is not None:
            self.maximum_occupancy = self._define_object(
                maximum_occupancy, RoomMaximumOccupancyDto
            )
        if number_of_rooms is not None:
            self.number_of_rooms = self._define_object(
                number_of_rooms, NumberOfRoomsDto
            )
        if room_type is not None:
            self.room_type = room_type
        if size is not None:
            self.size = size



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class CoordinatesDto(BaseModel):
    """A signed integer number that uniquely identifies a city.

    :param latitude: Latitude., defaults to None
    :type latitude: float, optional
    :param longitude: Longitude., defaults to None
    :type longitude: float, optional
    """

    def __init__(self, latitude: float = None, longitude: float = None):
        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TranslationDto(BaseModel):
    """TranslationDto

    :param language: language, defaults to None
    :type language: str, optional
    :param name: name, defaults to None
    :type name: str, optional
    """

    def __init__(self, language: str = None, name: str = None):
        if language is not None:
            self.language = language
        if name is not None:
            self.name = name



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .photo_url_dto import PhotoUrlDto


@JsonMap({})
class PhotoDto(BaseModel):
    """PhotoDto

    :param main_photo: Flags this as the main photo. Not returned otherwise., defaults to None
    :type main_photo: bool, optional
    :param tags: A list of tags associated with the photo. Manually generated., defaults to None
    :type tags: List[str], optional
    :param url: url, defaults to None
    :type url: PhotoUrlDto, optional
    """

    def __init__(
        self, main_photo: bool = None, tags: List[str] = None, url: PhotoUrlDto = None
    ):
        if main_photo is not None:
            self.main_photo = main_photo
        if tags is not None:
            self.tags = tags
        if url is not None:
            self.url = self._define_object(url, PhotoUrlDto)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .booker_input_dto import BookerInputDto
from .guests_input_dto import GuestsInputDto
from .coordinates import Coordinates


class SearchInputDtoExtras(Enum):
    """An enumeration representing different categories.

    :cvar EXTRA_CHARGES: "EXTRA_CHARGES"
    :vartype EXTRA_CHARGES: str
    :cvar PRODUCTS: "PRODUCTS"
    :vartype PRODUCTS: str
    """

    EXTRA_CHARGES = "EXTRA_CHARGES"
    PRODUCTS = "PRODUCTS"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, SearchInputDtoExtras._member_map_.values()))


@JsonMap({})
class SearchInputDto(BaseModel):
    """SearchInputDto

    :param checkin: The checkin date. Must be within 500 days in the future and in the format yyyy-mm-dd.
    :type checkin: str
    :param checkout: The checkout date. Must be later than {checkin}. Must be between 1 and 90 days after {checkin}. Must be within 500 days in the future and in the format yyyy-mm-dd.
    :type checkout: str
    :param booker: The booker's information.
    :type booker: BookerInputDto
    :param currency: A three-letter code that uniquely identifies a monetary currency as defined by the ISO 4217 standard., defaults to None
    :type currency: str, optional
    :param city: A signed integer number that uniquely identifies a city. , defaults to None
    :type city: int, optional
    :param country: A two-letter code that uniquely identifies a country. This code is defined by the ISO 3166-1 alpha-2 standard (ISO2) as described here: https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2. , defaults to None
    :type country: str, optional
    :param guests: The guest details for the request.
    :type guests: GuestsInputDto
    :param extras: Input parameter to request for additional information about the products., defaults to None
    :type extras: List[SearchInputDtoExtras], optional
    :param accommodations: A signed integer number that uniquely identifies an accommodation property., defaults to None
    :type accommodations: List[int], optional
    :param accommodation_facilities: A signed integer number that uniquely identifies an accommodation facility., defaults to None
    :type accommodation_facilities: List[int], optional
    :param room_facilities: A signed integer number that uniquely identifies a room facility., defaults to None
    :type room_facilities: List[int], optional
    :param accommodation_types: A signed integer number that uniquely identifies an accommodation type., defaults to None
    :type accommodation_types: List[int], optional
    :param brands: A signed integer number that uniquely identifies a brand., defaults to None
    :type brands: List[int], optional
    :param airport: A three-letter code that uniquely identifies an airport as defined by the International Air Transport Association (IATA)., defaults to None
    :type airport: str, optional
    :param district: A signed integer number that uniquely identifies a district. Typically, districts define known areas within a city., defaults to None
    :type district: int, optional
    :param landmark: A signed integer number that uniquely identifies a relevant geographical landmark, like a monument or a natural attraction., defaults to None
    :type landmark: int, optional
    :param coordinates: Limit the result list to the specified coordinates., defaults to None
    :type coordinates: Coordinates, optional
    :param region: A signed integer number that uniquely identifies a geographical region. Regions usually define official administrative areas within a country, but may also include multiple countries and in some cases un-official but popular designations for geographical areas. An example of a region that crosses multiple countries is the Alps in Europe. , defaults to None
    :type region: int, optional
    :param rows: The maximum number of results to return., defaults to None
    :type rows: int, optional
    :param page: Pagination token used to retrieve the next page of results. Obtained from `next_page`., defaults to None
    :type page: str, optional
    """

    def __init__(
        self,
        checkin: str,
        checkout: str,
        booker: BookerInputDto,
        guests: GuestsInputDto,
        currency: str = None,
        city: int = None,
        country: str = None,
        extras: List[SearchInputDtoExtras] = None,
        accommodations: List[int] = None,
        accommodation_facilities: List[int] = None,
        room_facilities: List[int] = None,
        accommodation_types: List[int] = None,
        brands: List[int] = None,
        airport: str = None,
        district: int = None,
        landmark: int = None,
        coordinates: Coordinates = None,
        region: int = None,
        rows: int = None,
        page: str = None,
    ):
        self.checkin = checkin
        self.checkout = checkout
        self.booker = self._define_object(booker, BookerInputDto)
        if currency is not None:
            self.currency = self._pattern_matching(currency, "^[A-Z]{3}$", "currency")
        if city is not None:
            self.city = city
        if country is not None:
            self.country = self._pattern_matching(country, "^[a-z]{2}$", "country")
        self.guests = self._define_object(guests, GuestsInputDto)
        if extras is not None:
            self.extras = self._define_list(extras, SearchInputDtoExtras)
        if accommodations is not None:
            self.accommodations = accommodations
        if accommodation_facilities is not None:
            self.accommodation_facilities = accommodation_facilities
        if room_facilities is not None:
            self.room_facilities = room_facilities
        if accommodation_types is not None:
            self.accommodation_types = accommodation_types
        if brands is not None:
            self.brands = brands
        if airport is not None:
            self.airport = self._pattern_matching(airport, "^[A-Z]{3}$", "airport")
        if district is not None:
            self.district = district
        if landmark is not None:
            self.landmark = landmark
        if coordinates is not None:
            self.coordinates = self._define_object(coordinates, Coordinates)
        if region is not None:
            self.region = region
        if rows is not None:
            self.rows = rows
        if page is not None:
            self.page = page



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class BedDto(BaseModel):
    """Detail list of all different types and number of beds included in this configuration.

    :param bed_type: A signed integer number that uniquely identifies a bed type. Examples of bed types are: Single, Double etc., defaults to None
    :type bed_type: int, optional
    :param number_of_beds: Number of similar beds included in this configuration., defaults to None
    :type number_of_beds: int, optional
    """

    def __init__(self, bed_type: int = None, number_of_beds: int = None):
        if bed_type is not None:
            self.bed_type = bed_type
        if number_of_beds is not None:
            self.number_of_beds = number_of_beds



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .translation_dto import TranslationDto


@JsonMap({})
class HotelFacilityTypeOutputDto(BaseModel):
    """HotelFacilityTypeOutputDto

    :param hotel_facility_type_id: Unique ID of the hotel facility type., defaults to None
    :type hotel_facility_type_id: int, optional
    :param facility_type_id: The type of facility this is, mapped from FacilityTypes., defaults to None
    :type facility_type_id: int, optional
    :param name: The name of this facility type in english., defaults to None
    :type name: str, optional
    :param translations: The fields and their translations in various languages. They are only shown if we have the translations available., defaults to None
    :type translations: List[TranslationDto], optional
    """

    def __init__(
        self,
        hotel_facility_type_id: int = None,
        facility_type_id: int = None,
        name: str = None,
        translations: List[TranslationDto] = None,
    ):
        if hotel_facility_type_id is not None:
            self.hotel_facility_type_id = hotel_facility_type_id
        if facility_type_id is not None:
            self.facility_type_id = facility_type_id
        if name is not None:
            self.name = name
        if translations is not None:
            self.translations = self._define_list(translations, TranslationDto)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class HotelsInputDtoLanguage(Enum):
    """An enumeration representing different categories.

    :cvar AR: "AR"
    :vartype AR: str
    :cvar BG: "BG"
    :vartype BG: str
    :cvar CA: "CA"
    :vartype CA: str
    :cvar CS: "CS"
    :vartype CS: str
    :cvar DA: "DA"
    :vartype DA: str
    :cvar DE: "DE"
    :vartype DE: str
    :cvar EL: "EL"
    :vartype EL: str
    :cvar EN: "EN"
    :vartype EN: str
    :cvar EN_GB: "EN_GB"
    :vartype EN_GB: str
    :cvar EN_US: "EN_US"
    :vartype EN_US: str
    :cvar ES: "ES"
    :vartype ES: str
    :cvar ES_AR: "ES_AR"
    :vartype ES_AR: str
    :cvar ES_MX: "ES_MX"
    :vartype ES_MX: str
    :cvar ET: "ET"
    :vartype ET: str
    :cvar FI: "FI"
    :vartype FI: str
    :cvar FR: "FR"
    :vartype FR: str
    :cvar HE: "HE"
    :vartype HE: str
    :cvar HI: "HI"
    :vartype HI: str
    :cvar HR: "HR"
    :vartype HR: str
    :cvar HU: "HU"
    :vartype HU: str
    :cvar ID: "ID"
    :vartype ID: str
    :cvar IS: "IS"
    :vartype IS: str
    :cvar IT: "IT"
    :vartype IT: str
    :cvar JA: "JA"
    :vartype JA: str
    :cvar KA: "KA"
    :vartype KA: str
    :cvar KO: "KO"
    :vartype KO: str
    :cvar LT: "LT"
    :vartype LT: str
    :cvar LV: "LV"
    :vartype LV: str
    :cvar MS: "MS"
    :vartype MS: str
    :cvar NL: "NL"
    :vartype NL: str
    :cvar NO: "NO"
    :vartype NO: str
    :cvar PL: "PL"
    :vartype PL: str
    :cvar PT_BR: "PT_BR"
    :vartype PT_BR: str
    :cvar PT_PT: "PT_PT"
    :vartype PT_PT: str
    :cvar RO: "RO"
    :vartype RO: str
    :cvar RU: "RU"
    :vartype RU: str
    :cvar SK: "SK"
    :vartype SK: str
    :cvar SL: "SL"
    :vartype SL: str
    :cvar SR: "SR"
    :vartype SR: str
    :cvar SV: "SV"
    :vartype SV: str
    :cvar TH: "TH"
    :vartype TH: str
    :cvar TL: "TL"
    :vartype TL: str
    :cvar TR: "TR"
    :vartype TR: str
    :cvar UK: "UK"
    :vartype UK: str
    :cvar VI: "VI"
    :vartype VI: str
    :cvar ZH_CN: "ZH_CN"
    :vartype ZH_CN: str
    :cvar ZH_TW: "ZH_TW"
    :vartype ZH_TW: str
    """

    AR = "AR"
    BG = "BG"
    CA = "CA"
    CS = "CS"
    DA = "DA"
    DE = "DE"
    EL = "EL"
    EN = "EN"
    EN_GB = "EN_GB"
    EN_US = "EN_US"
    ES = "ES"
    ES_AR = "ES_AR"
    ES_MX = "ES_MX"
    ET = "ET"
    FI = "FI"
    FR = "FR"
    HE = "HE"
    HI = "HI"
    HR = "HR"
    HU = "HU"
    ID = "ID"
    IS = "IS"
    IT = "IT"
    JA = "JA"
    KA = "KA"
    KO = "KO"
    LT = "LT"
    LV = "LV"
    MS = "MS"
    NL = "NL"
    NO = "NO"
    PL = "PL"
    PT_BR = "PT_BR"
    PT_PT = "PT_PT"
    RO = "RO"
    RU = "RU"
    SK = "SK"
    SL = "SL"
    SR = "SR"
    SV = "SV"
    TH = "TH"
    TL = "TL"
    TR = "TR"
    UK = "UK"
    VI = "VI"
    ZH_CN = "ZH_CN"
    ZH_TW = "ZH_TW"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, HotelsInputDtoLanguage._member_map_.values())
        )


class HotelsInputDtoExtras(Enum):
    """An enumeration representing different categories.

    :cvar HOTEL_INFO: "HOTEL_INFO"
    :vartype HOTEL_INFO: str
    :cvar ROOM_INFO: "ROOM_INFO"
    :vartype ROOM_INFO: str
    :cvar KEY_COLLECTION_INFO: "KEY_COLLECTION_INFO"
    :vartype KEY_COLLECTION_INFO: str
    :cvar HOTEL_FACILITIES: "HOTEL_FACILITIES"
    :vartype HOTEL_FACILITIES: str
    :cvar HOTEL_PHOTOS: "HOTEL_PHOTOS"
    :vartype HOTEL_PHOTOS: str
    :cvar HOTEL_DESCRIPTION: "HOTEL_DESCRIPTION"
    :vartype HOTEL_DESCRIPTION: str
    """

    HOTEL_INFO = "HOTEL_INFO"
    ROOM_INFO = "ROOM_INFO"
    KEY_COLLECTION_INFO = "KEY_COLLECTION_INFO"
    HOTEL_FACILITIES = "HOTEL_FACILITIES"
    HOTEL_PHOTOS = "HOTEL_PHOTOS"
    HOTEL_DESCRIPTION = "HOTEL_DESCRIPTION"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, HotelsInputDtoExtras._member_map_.values()))


@JsonMap({})
class HotelsInputDto(BaseModel):
    """HotelsInputDto

    :param hotel_ids: A list of up to 1000 hotel ids., defaults to None
    :type hotel_ids: List[int], optional
    :param language: The language code to return the results in. Please check the "Possible Values" section of the documentation for the accepted language codes. , defaults to None
    :type language: HotelsInputDtoLanguage, optional
    :param extras: Returns extra bits of information about hotels., defaults to None
    :type extras: List[HotelsInputDtoExtras], optional
    :param offset: The number of rows to offset the results by. NOTE: this needs to be 0 or a multiple of 100., defaults to None
    :type offset: int, optional
    :param rows: The maximum number of rows to return. NOTE: this needs to be a multiple of 100., defaults to None
    :type rows: int, optional
    """

    def __init__(
        self,
        hotel_ids: List[int] = None,
        language: HotelsInputDtoLanguage = None,
        extras: List[HotelsInputDtoExtras] = None,
        offset: int = None,
        rows: int = None,
    ):
        if hotel_ids is not None:
            self.hotel_ids = hotel_ids
        if language is not None:
            self.language = self._enum_matching(
                language, HotelsInputDtoLanguage.list(), "language"
            )
        if extras is not None:
            self.extras = self._define_list(extras, HotelsInputDtoExtras)
        if offset is not None:
            self.offset = offset
        if rows is not None:
            self.rows = rows



# This file was generated by liblab | https://liblab.com/

from typing import Dict

from .base_header import BaseHeader


class ApiKeyAuth(BaseHeader):
    """
    A class for handling API key authentication in headers.

    :ivar str _api_key: The API key.
    :ivar str _api_key_header: The header field for the API key.
    """

    _api_key: str
    _api_key_header: str

    def __init__(self, api_key: str, api_key_header="X-Affiliate-id"):
        """
        Initialize the ApiKeyAuth instance.

        :param api_key: The API key.
        :type api_key: str
        :param api_key_header: The header field for the API key.
        :type api_key_header: str
        """
        self._api_key = api_key
        self._api_key_header = api_key_header

    def set_value(self, value: str) -> None:
        """
        Set the value of the API key.

        :param value: The new value of the API key.
        :type value: str
        """
        self._api_key = value

    def get_headers(self) -> Dict[str, str]:
        """
        Get the headers with the API key field set to the API key.

        :return: A dictionary with the API key field set to the API key.
        :rtype: Dict[str, str]
        """
        return {self._api_key_header: self._api_key}



# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelThemeTypeInputDto(BaseModel):
    """HotelThemeTypeInputDto

    :param theme_ids: Limit the results to these themes., defaults to None
    :type theme_ids: List[int], optional
    :param offset: The number of rows to offset the results by. NOTE: this needs to be 0 or a multiple of 100., defaults to None
    :type offset: int, optional
    :param row: The maximum number of rows to return. NOTE: this needs to be a multiple of 100., defaults to None
    :type row: int, optional
    """

    def __init__(
        self, theme_ids: List[int] = None, offset: int = None, row: int = None
    ):
        if theme_ids is not None:
            self.theme_ids = theme_ids
        if offset is not None:
            self.offset = offset
        if row is not None:
            self.row = row



# This file was generated by liblab | https://liblab.com/

from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..models.utils.cast_models import cast_models
from ..models.search_input_dto import SearchInputDto
from ..models.search_accept import SearchAccept
from ..models.response_output_list_search_output_dto import (
    ResponseOutputListSearchOutputDto,
)
from ..models.response_output_list_details_output_dto import (
    ResponseOutputListDetailsOutputDto,
)
from ..models.response_output_constants_output_dto import (
    ResponseOutputConstantsOutputDto,
)
from ..models.post_details_accept import PostDetailsAccept
from ..models.get_accommodation_constants_accept import GetAccommodationConstantsAccept
from ..models.details_input_dto import DetailsInputDto
from ..models.constant_input_dto import ConstantInputDto


class DemandApiV3CompatibleService(BaseService):

    @cast_models
    def search(
        self, request_body: SearchInputDto, accept: SearchAccept = None
    ) -> ResponseOutputListSearchOutputDto:
        """This endpoint returns the cheapest available product for each hotel matching the search criteria.

        :param request_body: The request body.
        :type request_body: SearchInputDto
        :param accept: accept, defaults to None
        :type accept: SearchAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputListSearchOutputDto
        """

        Validator(SearchInputDto).validate(request_body)
        Validator(SearchAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v3-compatible/search",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response = self.send_request(serialized_request)

        return ResponseOutputListSearchOutputDto._unmap(response)

    @cast_models
    def post_details(
        self, request_body: DetailsInputDto, accept: PostDetailsAccept = None
    ) -> ResponseOutputListDetailsOutputDto:
        """This endpoint returns detailed information on all accommodation properties matching a given search criteria.
        By default, only basic information is returned. To receive extended information use the `extras` parameter.
        Is is mandatory to pass one of the input parameters: accommodations, airport, city, country or region.

        :param request_body: The request body.
        :type request_body: DetailsInputDto
        :param accept: accept, defaults to None
        :type accept: PostDetailsAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputListDetailsOutputDto
        """

        Validator(DetailsInputDto).validate(request_body)
        Validator(PostDetailsAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v3-compatible/details",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response = self.send_request(serialized_request)

        return ResponseOutputListDetailsOutputDto._unmap(response)

    @cast_models
    def get_accommodation_constants(
        self,
        request_body: ConstantInputDto = None,
        accept: GetAccommodationConstantsAccept = None,
    ) -> ResponseOutputConstantsOutputDto:
        """This endpoint enumerates the internal codes and names, in the selected languages,
        for relevant accommodation specific types.

        These accommodation specific types include the list of facilities
        that may be available at a property like "Elevator" or "Swimmingpool Outdoor".

        For example, the following parameters will return
        the full list in English (US) and French: `{"languages":"en-us","fr"}`.

        To get the full list call the endpoint passing an empty body.
        The codes returned are what is used as input and output for other endpoints in the accommodations namespace.

        :param request_body: The request body., defaults to None
        :type request_body: ConstantInputDto, optional
        :param accept: accept, defaults to None
        :type accept: GetAccommodationConstantsAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputConstantsOutputDto
        """

        Validator(ConstantInputDto).is_optional().validate(request_body)
        Validator(GetAccommodationConstantsAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v3-compatible/constants",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .serialize()
            .set_method("POST")
            .set_body(request_body)
        )

        response = self.send_request(serialized_request)

        return ResponseOutputConstantsOutputDto._unmap(response)



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ProgramSettingsDto(BaseModel):
    """Details of programmes undergone by the property.

    :param travel_proud: Boolean value is "true" if property has travel proud badge and "false" otherwise., defaults to None
    :type travel_proud: bool, optional
    """

    def __init__(self, travel_proud: bool = None):
        if travel_proud is not None:
            self.travel_proud = travel_proud



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .price_data_dto_double import PriceDataDtoDouble
from .product_dto import ProductDto


@JsonMap({"id_": "id"})
class SearchOutputDto(BaseModel):
    """SearchOutputDto

    :param id_: A signed integer number that uniquely identifies an accommodation property., defaults to None
    :type id_: int, optional
    :param currency: A three-letter code that uniquely identifies a monetary currency as defined by the ISO 4217 standard., defaults to None
    :type currency: str, optional
    :param deep_link_url: Deep link mobile app URL., defaults to None
    :type deep_link_url: str, optional
    :param url: Internet address for the property page on Booking.com., defaults to None
    :type url: str, optional
    :param price: The price components of this product or selection of products. 'base' and 'extra_charges' are returned only when explicitly requested (via 'extras=extra_charges')., defaults to None
    :type price: PriceDataDtoDouble, optional
    :param products: products, defaults to None
    :type products: List[ProductDto], optional
    """

    def __init__(
        self,
        id_: int = None,
        currency: str = None,
        deep_link_url: str = None,
        url: str = None,
        price: PriceDataDtoDouble = None,
        products: List[ProductDto] = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if currency is not None:
            self.currency = self._pattern_matching(currency, "^[A-Z]{3}$", "currency")
        if deep_link_url is not None:
            self.deep_link_url = deep_link_url
        if url is not None:
            self.url = url
        if price is not None:
            self.price = self._define_object(price, PriceDataDtoDouble)
        if products is not None:
            self.products = self._define_list(products, ProductDto)



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelPhotoDto(BaseModel):
    """Photos specific information of the hotel.

    :param main_photo: Is this the main hotel photo., defaults to None
    :type main_photo: bool, optional
    :param url_original: Url of the photo with max width of 500 pixels., defaults to None
    :type url_original: str, optional
    """

    def __init__(self, main_photo: bool = None, url_original: str = None):
        if main_photo is not None:
            self.main_photo = main_photo
        if url_original is not None:
            self.url_original = url_original



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .allocation_input_dto import AllocationInputDto


@JsonMap({})
class GuestsInputDto(BaseModel):
    """The guest details for the request.

    :param number_of_adults: The number of adults for the search.
    :type number_of_adults: int
    :param number_of_rooms: The number of rooms needed.
    :type number_of_rooms: int
    :param allocation: The exact allocation of guests to rooms., defaults to None
    :type allocation: List[AllocationInputDto], optional
    :param children: Array with the children ages., defaults to None
    :type children: List[int], optional
    """

    def __init__(
        self,
        number_of_adults: int,
        number_of_rooms: int,
        allocation: List[AllocationInputDto] = None,
        children: List[int] = None,
    ):
        self.number_of_adults = number_of_adults
        self.number_of_rooms = number_of_rooms
        if allocation is not None:
            self.allocation = self._define_list(allocation, AllocationInputDto)
        if children is not None:
            self.children = children



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class LocalTime(BaseModel):
    """The time till when checkout can be done at this property.

    :param hour: hour, defaults to None
    :type hour: int, optional
    :param minute: minute, defaults to None
    :type minute: int, optional
    :param second: second, defaults to None
    :type second: int, optional
    :param nano: nano, defaults to None
    :type nano: int, optional
    """

    def __init__(
        self, hour: int = None, minute: int = None, second: int = None, nano: int = None
    ):
        if hour is not None:
            self.hour = hour
        if minute is not None:
            self.minute = minute
        if second is not None:
            self.second = second
        if nano is not None:
            self.nano = nano



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .translation_dto import TranslationDto


@JsonMap({})
class HotelTypesOutputDto(BaseModel):
    """HotelTypesOutputDto

    :param translations: translations, defaults to None
    :type translations: List[TranslationDto], optional
    :param name: name, defaults to None
    :type name: str, optional
    :param hotel_type_id: hotel_type_id, defaults to None
    :type hotel_type_id: int, optional
    """

    def __init__(
        self,
        translations: List[TranslationDto] = None,
        name: str = None,
        hotel_type_id: int = None,
    ):
        if translations is not None:
            self.translations = self._define_list(translations, TranslationDto)
        if name is not None:
            self.name = name
        if hotel_type_id is not None:
            self.hotel_type_id = hotel_type_id



# This file was generated by liblab | https://liblab.com/

from enum import Enum


class GetHotelsAccept(Enum):
    """An enumeration representing different categories.

    :cvar APPLICATION_JSON_APPLICATION_XML: "application/json, application/xml"
    :vartype APPLICATION_JSON_APPLICATION_XML: str
    """

    APPLICATION_JSON_APPLICATION_XML = "application/json, application/xml"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, GetHotelsAccept._member_map_.values()))



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class QuestionDto(BaseModel):
    """Review scores per question.

    :param count: Number of reviewers that answered the question., defaults to None
    :type count: int, optional
    :param question: Localized question text. See language=... input parameter., defaults to None
    :type question: str, optional
    :param question_literal: Question literal., defaults to None
    :type question_literal: str, optional
    :param score: Average score that reviewers provided in response to this question., defaults to None
    :type score: float, optional
    """

    def __init__(
        self,
        count: int = None,
        question: str = None,
        question_literal: str = None,
        score: float = None,
    ):
        if count is not None:
            self.count = count
        if question is not None:
            self.question = question
        if question_literal is not None:
            self.question_literal = question_literal
        if score is not None:
            self.score = score



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .bed_configuration_dto import BedConfigurationDto


@JsonMap({})
class BedroomDto(BaseModel):
    """BedroomDto

    :param bed_configurations: bed_configurations, defaults to None
    :type bed_configurations: List[BedConfigurationDto], optional
    """

    def __init__(self, bed_configurations: List[BedConfigurationDto] = None):
        if bed_configurations is not None:
            self.bed_configurations = self._define_list(
                bed_configurations, BedConfigurationDto
            )



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .translated_string import TranslatedString
from .checkin_checkout_times_dto import CheckinCheckoutTimesDto
from .contacts_dto import ContactsDto
from .facility_dto import FacilityDto
from .description_dto import DescriptionDto
from .key_collection_information_dto import KeyCollectionInformationDto
from .location_dto import LocationDto
from .payment_dto import PaymentDto
from .photo_dto import PhotoDto
from .policies_dto import PoliciesDto
from .program_settings_dto import ProgramSettingsDto
from .rating_dto import RatingDto
from .room_dto import RoomDto


@JsonMap({"id_": "id"})
class DetailsOutputDto(BaseModel):
    """DetailsOutputDto

    :param id_: A signed integer number that uniquely identifies an accommodation property., defaults to None
    :type id_: int, optional
    :param name: Translated description of this room. The maximum number of characters returned may be limited by contract., defaults to None
    :type name: TranslatedString, optional
    :param accommodation_type: A signed integer number that uniquely identifies an accommodation property type. Examples of accommodation types are: Apartment, Hostel, Hotel etc., defaults to None
    :type accommodation_type: int, optional
    :param brands: A signed integer number that uniquely identifies an accommodation brand., defaults to None
    :type brands: List[int], optional
    :param checkin_checkout_times: checkin_checkout_times, defaults to None
    :type checkin_checkout_times: CheckinCheckoutTimesDto, optional
    :param contacts: Contact information of the accommodation., defaults to None
    :type contacts: ContactsDto, optional
    :param currency: A three-letter code that uniquely identifies a monetary currency as defined by the ISO 4217 standard., defaults to None
    :type currency: str, optional
    :param facilities: The list of facilities available in this property. Requires `{"extras":["facilities"]}`., defaults to None
    :type facilities: List[FacilityDto], optional
    :param deep_link_url: Deep link mobile app URL., defaults to None
    :type deep_link_url: str, optional
    :param description: Textual information about the accommodation. Requires `{"extras":["description"]}`., defaults to None
    :type description: DescriptionDto, optional
    :param is_work_friendly: Flags if this accommodation is work friendly., defaults to None
    :type is_work_friendly: bool, optional
    :param key_collection_information: key_collection_information, defaults to None
    :type key_collection_information: List[KeyCollectionInformationDto], optional
    :param location: All location related information of this accommodation property., defaults to None
    :type location: LocationDto, optional
    :param number_of_rooms: Total number of rooms in the property. Please note that this is not an availability call and that this number is mostly used to determine the size and type of a property. , defaults to None
    :type number_of_rooms: int, optional
    :param payment: Payment terms and conditions for this product., defaults to None
    :type payment: PaymentDto, optional
    :param photos: List of photos for this accommodation property.The maximum number of photos returned may be limited by contract. Requires `{"extras":["photos"]}`. The photos are returned in no particular order., defaults to None
    :type photos: List[PhotoDto], optional
    :param policies: The policies for this product., defaults to None
    :type policies: PoliciesDto, optional
    :param price_category: Indicates the qualitative price reference (between $ and $$$$) on how expensive an accommodation is. Accommodations in the same city are sorted by ascending price (average per guest per night in the last month), the ones in the lowest 25 percentile are in category $, between 25 and 50 percentile are in category $$, between 50 and 75 percentile are in category $$$, remaining ones are in category $$$$., defaults to None
    :type price_category: str, optional
    :param programmes: Details of programmes undergone by the property., defaults to None
    :type programmes: ProgramSettingsDto, optional
    :param rating: rating, defaults to None
    :type rating: RatingDto, optional
    :param rooms: The list of room types available at this property. Requires `{"extras":["rooms"]}`., defaults to None
    :type rooms: List[RoomDto], optional
    :param spoken_languages: spoken_languages, defaults to None
    :type spoken_languages: List[str], optional
    :param themes: themes, defaults to None
    :type themes: List[int], optional
    :param url: url, defaults to None
    :type url: str, optional
    """

    def __init__(
        self,
        id_: int = None,
        name: TranslatedString = None,
        accommodation_type: int = None,
        brands: List[int] = None,
        checkin_checkout_times: CheckinCheckoutTimesDto = None,
        contacts: ContactsDto = None,
        currency: str = None,
        facilities: List[FacilityDto] = None,
        deep_link_url: str = None,
        description: DescriptionDto = None,
        is_work_friendly: bool = None,
        key_collection_information: List[KeyCollectionInformationDto] = None,
        location: LocationDto = None,
        number_of_rooms: int = None,
        payment: PaymentDto = None,
        photos: List[PhotoDto] = None,
        policies: PoliciesDto = None,
        price_category: str = None,
        programmes: ProgramSettingsDto = None,
        rating: RatingDto = None,
        rooms: List[RoomDto] = None,
        spoken_languages: List[str] = None,
        themes: List[int] = None,
        url: str = None,
    ):
        if id_ is not None:
            self.id_ = id_
        if name is not None:
            self.name = self._define_object(name, TranslatedString)
        if accommodation_type is not None:
            self.accommodation_type = accommodation_type
        if brands is not None:
            self.brands = brands
        if checkin_checkout_times is not None:
            self.checkin_checkout_times = self._define_object(
                checkin_checkout_times, CheckinCheckoutTimesDto
            )
        if contacts is not None:
            self.contacts = self._define_object(contacts, ContactsDto)
        if currency is not None:
            self.currency = self._pattern_matching(currency, "^[A-Z]{3}$", "currency")
        if facilities is not None:
            self.facilities = self._define_list(facilities, FacilityDto)
        if deep_link_url is not None:
            self.deep_link_url = deep_link_url
        if description is not None:
            self.description = self._define_object(description, DescriptionDto)
        if is_work_friendly is not None:
            self.is_work_friendly = is_work_friendly
        if key_collection_information is not None:
            self.key_collection_information = self._define_list(
                key_collection_information, KeyCollectionInformationDto
            )
        if location is not None:
            self.location = self._define_object(location, LocationDto)
        if number_of_rooms is not None:
            self.number_of_rooms = number_of_rooms
        if payment is not None:
            self.payment = self._define_object(payment, PaymentDto)
        if photos is not None:
            self.photos = self._define_list(photos, PhotoDto)
        if policies is not None:
            self.policies = self._define_object(policies, PoliciesDto)
        if price_category is not None:
            self.price_category = self._pattern_matching(
                price_category, "[$]{0,4}", "price_category"
            )
        if programmes is not None:
            self.programmes = self._define_object(programmes, ProgramSettingsDto)
        if rating is not None:
            self.rating = self._define_object(rating, RatingDto)
        if rooms is not None:
            self.rooms = self._define_list(rooms, RoomDto)
        if spoken_languages is not None:
            self.spoken_languages = spoken_languages
        if themes is not None:
            self.themes = themes
        if url is not None:
            self.url = url



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .block_output_dto import BlockOutputDto


@JsonMap({"is_flash_deal": "isFlashDeal"})
class BlockAvailabilityOutputDto(BaseModel):
    """BlockAvailabilityOutputDto

    :param block: The object containing all the relevant information for the combination of room, policy, meal and occupancy that determines the price." A block is the unique entity you book with booking.com., defaults to None
    :type block: List[BlockOutputDto], optional
    :param can_pay_now: Boolean value set to "true" if payment can be made during reservation process or "false" if it can not., defaults to None
    :type can_pay_now: bool, optional
    :param checkin: The date that was searched for as checkin. Format: YYYY-MM-DD, defaults to None
    :type checkin: str, optional
    :param checkout: The date that was searched for as checkout. Format: YYYY-MM-DD, defaults to None
    :type checkout: str, optional
    :param direct_payment: Boolean value set to "true" if the direct payment is available or "false" if it is not., defaults to None
    :type direct_payment: bool, optional
    :param hotel_id: Booking.com hotel ID. The unique identifier of this hotel., defaults to None
    :type hotel_id: int, optional
    :param hotel_url: URL of the hotel's page on Booking.com., defaults to None
    :type hotel_url: str, optional
    :param is_flash_deal: is_flash_deal, defaults to None
    :type is_flash_deal: bool, optional
    :param flash_deal: flash_deal, defaults to None
    :type flash_deal: bool, optional
    """

    def __init__(
        self,
        block: List[BlockOutputDto] = None,
        can_pay_now: bool = None,
        checkin: str = None,
        checkout: str = None,
        direct_payment: bool = None,
        hotel_id: int = None,
        hotel_url: str = None,
        is_flash_deal: bool = None,
        flash_deal: bool = None,
    ):
        if block is not None:
            self.block = self._define_list(block, BlockOutputDto)
        if can_pay_now is not None:
            self.can_pay_now = can_pay_now
        if checkin is not None:
            self.checkin = checkin
        if checkout is not None:
            self.checkout = checkout
        if direct_payment is not None:
            self.direct_payment = direct_payment
        if hotel_id is not None:
            self.hotel_id = hotel_id
        if hotel_url is not None:
            self.hotel_url = hotel_url
        if is_flash_deal is not None:
            self.is_flash_deal = is_flash_deal
        if flash_deal is not None:
            self.flash_deal = flash_deal



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .coordinates_dto import CoordinatesDto
from .checkin_checkout_times_dto import CheckinCheckoutTimesDto
from .hotel_photo_dto import HotelPhotoDto


@JsonMap({})
class HotelDataDto(BaseModel):
    """Hotel specific information.

    :param address: The street address of the hotel., defaults to None
    :type address: str, optional
    :param city_id: Id of the city where this property is located., defaults to None
    :type city_id: int, optional
    :param country: Two-letter ISO country code of the hotel., defaults to None
    :type country: str, optional
    :param location: A signed integer number that uniquely identifies a city., defaults to None
    :type location: CoordinatesDto, optional
    :param zip: Hotel ZIP code, defaults to None
    :type zip: str, optional
    :param currency: Three-letter ISO currency code for the hotel., defaults to None
    :type currency: str, optional
    :param checkin_checkout_times: checkin_checkout_times, defaults to None
    :type checkin_checkout_times: CheckinCheckoutTimesDto, optional
    :param hotel_photos: Photos specific information of the hotel., defaults to None
    :type hotel_photos: List[HotelPhotoDto], optional
    :param hotel_description: The description text for this hotel., defaults to None
    :type hotel_description: str, optional
    :param url: URL of the hotel's page on Booking.com., defaults to None
    :type url: str, optional
    :param deep_link_url: Deep link mobile app URL., defaults to None
    :type deep_link_url: str, optional
    :param region_ids: List of region_ids that the hotel belongs to, defaults to None
    :type region_ids: List[int], optional
    :param number_of_reviews: Number of reviews for this hotel., defaults to None
    :type number_of_reviews: int, optional
    :param review_score: Review score of this hotel., defaults to None
    :type review_score: float, optional
    :param spoken_languages: Languages spoken by the hotel's staff, defaults to None
    :type spoken_languages: List[str], optional
    """

    def __init__(
        self,
        address: str = None,
        city_id: int = None,
        country: str = None,
        location: CoordinatesDto = None,
        zip: str = None,
        currency: str = None,
        checkin_checkout_times: CheckinCheckoutTimesDto = None,
        hotel_photos: List[HotelPhotoDto] = None,
        hotel_description: str = None,
        url: str = None,
        deep_link_url: str = None,
        region_ids: List[int] = None,
        number_of_reviews: int = None,
        review_score: float = None,
        spoken_languages: List[str] = None,
    ):
        if address is not None:
            self.address = address
        if city_id is not None:
            self.city_id = city_id
        if country is not None:
            self.country = country
        if location is not None:
            self.location = self._define_object(location, CoordinatesDto)
        if zip is not None:
            self.zip = zip
        if currency is not None:
            self.currency = currency
        if checkin_checkout_times is not None:
            self.checkin_checkout_times = self._define_object(
                checkin_checkout_times, CheckinCheckoutTimesDto
            )
        if hotel_photos is not None:
            self.hotel_photos = self._define_list(hotel_photos, HotelPhotoDto)
        if hotel_description is not None:
            self.hotel_description = hotel_description
        if url is not None:
            self.url = url
        if deep_link_url is not None:
            self.deep_link_url = deep_link_url
        if region_ids is not None:
            self.region_ids = region_ids
        if number_of_reviews is not None:
            self.number_of_reviews = number_of_reviews
        if review_score is not None:
            self.review_score = review_score
        if spoken_languages is not None:
            self.spoken_languages = spoken_languages



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class Tags(Enum):
    """An enumeration representing different categories.

    :cvar BLACK_FRIDAY: "BLACK_FRIDAY"
    :vartype BLACK_FRIDAY: str
    :cvar GENIUS: "GENIUS"
    :vartype GENIUS: str
    :cvar LIMITED_TIME_DEAL: "LIMITED_TIME_DEAL"
    :vartype LIMITED_TIME_DEAL: str
    :cvar LOGGED_IN_DEAL: "LOGGED_IN_DEAL"
    :vartype LOGGED_IN_DEAL: str
    :cvar MOBILE_RATE: "MOBILE_RATE"
    :vartype MOBILE_RATE: str
    :cvar SEASONAL_DEAL: "SEASONAL_DEAL"
    :vartype SEASONAL_DEAL: str
    """

    BLACK_FRIDAY = "BLACK_FRIDAY"
    GENIUS = "GENIUS"
    LIMITED_TIME_DEAL = "LIMITED_TIME_DEAL"
    LOGGED_IN_DEAL = "LOGGED_IN_DEAL"
    MOBILE_RATE = "MOBILE_RATE"
    SEASONAL_DEAL = "SEASONAL_DEAL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Tags._member_map_.values()))


@JsonMap({})
class DealDto(BaseModel):
    """This specifies the deal tagging for the product.

    :param discount_percentage: discount_percentage, defaults to None
    :type discount_percentage: int, optional
    :param public_price: public_price, defaults to None
    :type public_price: float, optional
    :param tags: tags, defaults to None
    :type tags: List[Tags], optional
    """

    def __init__(
        self,
        discount_percentage: int = None,
        public_price: float = None,
        tags: List[Tags] = None,
    ):
        if discount_percentage is not None:
            self.discount_percentage = discount_percentage
        if public_price is not None:
            self.public_price = public_price
        if tags is not None:
            self.tags = self._define_list(tags, Tags)



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class AlternativeKeyLocationDto(BaseModel):
    """Alternate location to collect the key of this accommodation property.
    This is returned if the key to access the property is in another location.


    :param address: address, defaults to None
    :type address: dict, optional
    :param city: city, defaults to None
    :type city: dict, optional
    :param postal_code: postal_code, defaults to None
    :type postal_code: str, optional
    """

    def __init__(
        self, address: dict = None, city: dict = None, postal_code: str = None
    ):
        if address is not None:
            self.address = address
        if city is not None:
            self.city = city
        if postal_code is not None:
            self.postal_code = postal_code



# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TranslatedString(BaseModel):
    """Translated description of this room. The maximum number of characters returned may be limited by contract.

    :param translations: translations, defaults to None
    :type translations: dict, optional
    """

    def __init__(self, translations: dict = None):
        if translations is not None:
            self.translations = translations



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .bed_dto import BedDto


@JsonMap({"id_": "id"})
class BedConfigurationDto(BaseModel):
    """Lists all alternative bed configurations that are supported.

    :param id_: Uniquely identifies this bed configuration., defaults to None
    :type id_: str, optional
    :param configuration: Detail list of all different types and number of beds included in this configuration., defaults to None
    :type configuration: List[BedDto], optional
    """

    def __init__(self, id_: str = None, configuration: List[BedDto] = None):
        if id_ is not None:
            self.id_ = id_
        if configuration is not None:
            self.configuration = self._define_list(configuration, BedDto)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from .utils.json_map import JsonMap
from .base import BaseModel


class Mode(Enum):
    """An enumeration representing different categories.

    :cvar CALCULATED_AMOUNT: "CALCULATED_AMOUNT"
    :vartype CALCULATED_AMOUNT: str
    :cvar INCALCULABLE: "INCALCULABLE"
    :vartype INCALCULABLE: str
    :cvar PERCENTAGE: "PERCENTAGE"
    :vartype PERCENTAGE: str
    :cvar PER_NIGHT: "PER_NIGHT"
    :vartype PER_NIGHT: str
    :cvar PER_PERSON_PER_NIGHT: "PER_PERSON_PER_NIGHT"
    :vartype PER_PERSON_PER_NIGHT: str
    :cvar PER_PERSON_PER_STAY: "PER_PERSON_PER_STAY"
    :vartype PER_PERSON_PER_STAY: str
    :cvar PER_STAY: "PER_STAY"
    :vartype PER_STAY: str
    """

    CALCULATED_AMOUNT = "CALCULATED_AMOUNT"
    INCALCULABLE = "INCALCULABLE"
    PERCENTAGE = "PERCENTAGE"
    PER_NIGHT = "PER_NIGHT"
    PER_PERSON_PER_NIGHT = "PER_PERSON_PER_NIGHT"
    PER_PERSON_PER_STAY = "PER_PERSON_PER_STAY"
    PER_STAY = "PER_STAY"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Mode._member_map_.values()))


@JsonMap({})
class ChargeDto(BaseModel):
    """ChargeDto

    :param charge: charge, defaults to None
    :type charge: int, optional
    :param condition: condition, defaults to None
    :type condition: int, optional
    :param mode: mode, defaults to None
    :type mode: Mode, optional
    :param percentage: percentage, defaults to None
    :type percentage: float, optional
    :param total_amount: total_amount, defaults to None
    :type total_amount: float, optional
    :param unit_amount: unit_amount, defaults to None
    :type unit_amount: float, optional
    """

    def __init__(
        self,
        charge: int = None,
        condition: int = None,
        mode: Mode = None,
        percentage: float = None,
        total_amount: float = None,
        unit_amount: float = None,
    ):
        if charge is not None:
            self.charge = charge
        if condition is not None:
            self.condition = condition
        if mode is not None:
            self.mode = self._enum_matching(mode, Mode.list(), "mode")
        if percentage is not None:
            self.percentage = percentage
        if total_amount is not None:
            self.total_amount = total_amount
        if unit_amount is not None:
            self.unit_amount = unit_amount



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .room_info_dto import RoomInfoDto


@JsonMap({})
class RoomDataDto(BaseModel):
    """This block has room data for this hotel.

    :param room_id: room_id, defaults to None
    :type room_id: int, optional
    :param room_info: room_info, defaults to None
    :type room_info: RoomInfoDto, optional
    """

    def __init__(self, room_id: int = None, room_info: RoomInfoDto = None):
        if room_id is not None:
            self.room_id = room_id
        if room_info is not None:
            self.room_info = self._define_object(room_info, RoomInfoDto)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .question_dto import QuestionDto


@JsonMap({})
class ScoreBreakdown(BaseModel):
    """A breakdown of scores per reviewer type and review question.

    :param average_score: Average score from this reviewer type., defaults to None
    :type average_score: float, optional
    :param count: Number of responses from this reviewer type., defaults to None
    :type count: int, optional
    :param question: Review scores per question., defaults to None
    :type question: List[QuestionDto], optional
    :param reviewer_type: Reviewer type., defaults to None
    :type reviewer_type: str, optional
    """

    def __init__(
        self,
        average_score: float = None,
        count: int = None,
        question: List[QuestionDto] = None,
        reviewer_type: str = None,
    ):
        if average_score is not None:
            self.average_score = average_score
        if count is not None:
            self.count = count
        if question is not None:
            self.question = self._define_list(question, QuestionDto)
        if reviewer_type is not None:
            self.reviewer_type = reviewer_type



# This file was generated by liblab | https://liblab.com/

from .utils.validator import Validator
from .utils.base_service import BaseService
from ..net.transport.serializer import Serializer
from ..models.utils.cast_models import cast_models
from ..models.review_scores_input_dto import ReviewScoresInputDto
from ..models.response_output_v2_review_scores_output_dto import (
    ResponseOutputV2ReviewScoresOutputDto,
)
from ..models.response_output_v2_hotels_output_dto import (
    ResponseOutputV2HotelsOutputDto,
)
from ..models.response_output_v2_hotel_types_output_dto import (
    ResponseOutputV2HotelTypesOutputDto,
)
from ..models.response_output_v2_hotel_theme_types_output_dto import (
    ResponseOutputV2HotelThemeTypesOutputDto,
)
from ..models.response_output_v2_hotel_facility_type_output_dto import (
    ResponseOutputV2HotelFacilityTypeOutputDto,
)
from ..models.response_output_v2_hotel_availability_output_dto import (
    ResponseOutputV2HotelAvailabilityOutputDto,
)
from ..models.response_output_v2_block_availability_output_dto import (
    ResponseOutputV2BlockAvailabilityOutputDto,
)
from ..models.hotels_input_dto import HotelsInputDto
from ..models.hotel_type_input_dto import HotelTypeInputDto
from ..models.hotel_theme_type_input_dto import HotelThemeTypeInputDto
from ..models.hotel_facility_input_dto import HotelFacilityInputDto
from ..models.hotel_availability_input_dto import HotelAvailabilityInputDto
from ..models.get_room_facility_types_accept import GetRoomFacilityTypesAccept
from ..models.get_hotels_review_scores_accept import GetHotelsReviewScoresAccept
from ..models.get_hotels_accept import GetHotelsAccept
from ..models.get_hotel_types_accept import GetHotelTypesAccept
from ..models.get_hotel_theme_types_accept import GetHotelThemeTypesAccept
from ..models.get_hotel_availability_accept import GetHotelAvailabilityAccept
from ..models.get_block_availability_accept import GetBlockAvailabilityAccept
from ..models.block_availability_input_dto import BlockAvailabilityInputDto


class DemandApiV2CompatibleService(BaseService):

    @cast_models
    def get_hotels_review_scores(
        self,
        review_scores_input_dto: ReviewScoresInputDto,
        accept: GetHotelsReviewScoresAccept = None,
    ) -> ResponseOutputV2ReviewScoresOutputDto:
        """Gives information about review scores for specified hotel_ids and filter.
        The information consists of score breakdown per reviewer_type and review questions,
        and overall score distribution per score value (1 - 10).

        The available filter is input parameter reviewer_type=... .
        It allows generating review score information for just one reviewer type.

        Language in which the response is rendered can be controlled with the input parameter language=...
        (default: 'en'). Setting the language will reflect on the output fields question and review_score_word.

        One additional output field can be requested with input parameter extras=review_score_word.

        :param review_scores_input_dto: review_scores_input_dto
        :type review_scores_input_dto: ReviewScoresInputDto
        :param accept: accept, defaults to None
        :type accept: GetHotelsReviewScoresAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputV2ReviewScoresOutputDto
        """

        Validator(ReviewScoresInputDto).validate(review_scores_input_dto)
        Validator(GetHotelsReviewScoresAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v2-compatible/reviewScores",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .add_query("reviewScoresInputDto", review_scores_input_dto)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return ResponseOutputV2ReviewScoresOutputDto._unmap(response)

    @cast_models
    def get_hotels(
        self, hotels_input: HotelsInputDto, accept: GetHotelsAccept = None
    ) -> ResponseOutputV2HotelsOutputDto:
        """This call returns the hotel and room data. By default, only hotel_id is returned in the output.

        One of the argument: hotel_ids, city_ids, country_ids, region_ids, district_ids, chain_ids is mandatory.

        Additional data needs to be requested via extras parameter.

        The data is returned in English by default.

        :param hotels_input: hotels_input
        :type hotels_input: HotelsInputDto
        :param accept: accept, defaults to None
        :type accept: GetHotelsAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputV2HotelsOutputDto
        """

        Validator(HotelsInputDto).validate(hotels_input)
        Validator(GetHotelsAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v2-compatible/hotels",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .add_query("hotelsInput", hotels_input)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return ResponseOutputV2HotelsOutputDto._unmap(response)

    @cast_models
    def get_hotel_types(
        self,
        hotel_type_input_dto: HotelTypeInputDto,
        accept: GetHotelTypesAccept = None,
    ) -> ResponseOutputV2HotelTypesOutputDto:
        """This endpoint returns hotel types names and their translations. (EN is default)

        :param hotel_type_input_dto: hotel_type_input_dto
        :type hotel_type_input_dto: HotelTypeInputDto
        :param accept: accept, defaults to None
        :type accept: GetHotelTypesAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputV2HotelTypesOutputDto
        """

        Validator(HotelTypeInputDto).validate(hotel_type_input_dto)
        Validator(GetHotelTypesAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v2-compatible/hotelTypes",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .add_query("hotelTypeInputDTO", hotel_type_input_dto)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return ResponseOutputV2HotelTypesOutputDto._unmap(response)

    @cast_models
    def get_hotel_theme_types(
        self,
        hotel_theme_type_input_dto: HotelThemeTypeInputDto,
        accept: GetHotelThemeTypesAccept = None,
    ) -> ResponseOutputV2HotelThemeTypesOutputDto:
        """This endpoint returns a list of hotel theme types (in English).

        :param hotel_theme_type_input_dto: hotel_theme_type_input_dto
        :type hotel_theme_type_input_dto: HotelThemeTypeInputDto
        :param accept: accept, defaults to None
        :type accept: GetHotelThemeTypesAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputV2HotelThemeTypesOutputDto
        """

        Validator(HotelThemeTypeInputDto).validate(hotel_theme_type_input_dto)
        Validator(GetHotelThemeTypesAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v2-compatible/hotelThemeTypes",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .add_query("hotelThemeTypeInputDTO", hotel_theme_type_input_dto)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return ResponseOutputV2HotelThemeTypesOutputDto._unmap(response)

    @cast_models
    def get_room_facility_types(
        self,
        hotel_facility_input_dto: HotelFacilityInputDto,
        accept: GetRoomFacilityTypesAccept = None,
    ) -> ResponseOutputV2HotelFacilityTypeOutputDto:
        """This endpoint returns room facility types names and their translations (EN is default).

        :param hotel_facility_input_dto: hotel_facility_input_dto
        :type hotel_facility_input_dto: HotelFacilityInputDto
        :param accept: accept, defaults to None
        :type accept: GetRoomFacilityTypesAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputV2HotelFacilityTypeOutputDto
        """

        Validator(HotelFacilityInputDto).validate(hotel_facility_input_dto)
        Validator(GetRoomFacilityTypesAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v2-compatible/hotelFacilityTypes",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .add_query("hotelFacilityInputDto", hotel_facility_input_dto)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return ResponseOutputV2HotelFacilityTypeOutputDto._unmap(response)

    @cast_models
    def get_hotel_availability(
        self,
        hotel_availability_input_dto: HotelAvailabilityInputDto,
        accept: GetHotelAvailabilityAccept = None,
    ) -> ResponseOutputV2HotelAvailabilityOutputDto:
        """This endpoint returns the cheapest available room for each hotel matching your check-in and check-out dates.
        You can search for hotels in a city, or for a specific list of (upto 300) hotels by hotel_ids.
        Here you will find whether the price included breakfast or other meals, as well as whether it is possible to cancel for free.
        It is possible to have a breakdown of the price returned by this endpoint and to filter by property types and/or hotel facilities.

        :param hotel_availability_input_dto: hotel_availability_input_dto
        :type hotel_availability_input_dto: HotelAvailabilityInputDto
        :param accept: accept, defaults to None
        :type accept: GetHotelAvailabilityAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputV2HotelAvailabilityOutputDto
        """

        Validator(HotelAvailabilityInputDto).validate(hotel_availability_input_dto)
        Validator(GetHotelAvailabilityAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v2-compatible/hotelAvailability",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .add_query("hotelAvailabilityInputDto", hotel_availability_input_dto)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return ResponseOutputV2HotelAvailabilityOutputDto._unmap(response)

    @cast_models
    def get_block_availability(
        self,
        block_input: BlockAvailabilityInputDto,
        accept: GetBlockAvailabilityAccept = None,
    ) -> ResponseOutputV2BlockAvailabilityOutputDto:
        """This endpoint is where you find a list of all bookable or available rooms at a property.
        A room can have multiple blocks, as a block is a combination of the meal, cancellation policy, occupancy and other things.
        You can find detailed information about one hotel per search (detail_level)
        which will return most of the information needed to replicate the booking.com property page.

        If you want to search multiple hotels, you can, but you get less detail.
        For searching multiple hotels, it is recommended to use hotelAvailability.

        :param block_input: block_input
        :type block_input: BlockAvailabilityInputDto
        :param accept: accept, defaults to None
        :type accept: GetBlockAvailabilityAccept, optional
        ...
        :raises RequestError: Raised when a request fails, with optional HTTP status code and details.
        ...
        :return: OK
        :rtype: ResponseOutputV2BlockAvailabilityOutputDto
        """

        Validator(BlockAvailabilityInputDto).validate(block_input)
        Validator(GetBlockAvailabilityAccept).is_optional().validate(accept)

        serialized_request = (
            Serializer(
                f"{self.base_url}/demand-api-v2-compatible/blockAvailability",
                self.get_default_headers(),
            )
            .add_header("Accept", accept)
            .add_query("blockInput", block_input)
            .serialize()
            .set_method("GET")
        )

        response = self.send_request(serialized_request)

        return ResponseOutputV2BlockAvailabilityOutputDto._unmap(response)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class Platform(Enum):
    """An enumeration representing different categories.

    :cvar ANDROID: "ANDROID"
    :vartype ANDROID: str
    :cvar DESKTOP: "DESKTOP"
    :vartype DESKTOP: str
    :cvar IOS: "IOS"
    :vartype IOS: str
    :cvar MOBILE: "MOBILE"
    :vartype MOBILE: str
    :cvar TABLET: "TABLET"
    :vartype TABLET: str
    """

    ANDROID = "ANDROID"
    DESKTOP = "DESKTOP"
    IOS = "IOS"
    MOBILE = "MOBILE"
    TABLET = "TABLET"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Platform._member_map_.values()))


class TravelPurpose(Enum):
    """An enumeration representing different categories.

    :cvar BUSINESS: "BUSINESS"
    :vartype BUSINESS: str
    :cvar LEISURE: "LEISURE"
    :vartype LEISURE: str
    """

    BUSINESS = "BUSINESS"
    LEISURE = "LEISURE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, TravelPurpose._member_map_.values()))


class UserGroups(Enum):
    """An enumeration representing different categories.

    :cvar AUTHENTICATED: "AUTHENTICATED"
    :vartype AUTHENTICATED: str
    :cvar GENIUS: "GENIUS"
    :vartype GENIUS: str
    :cvar GENIUS2: "GENIUS2"
    :vartype GENIUS2: str
    :cvar GENIUS3: "GENIUS3"
    :vartype GENIUS3: str
    """

    AUTHENTICATED = "AUTHENTICATED"
    GENIUS = "GENIUS"
    GENIUS2 = "GENIUS2"
    GENIUS3 = "GENIUS3"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, UserGroups._member_map_.values()))


@JsonMap({})
class BookerInputDto(BaseModel):
    """The booker's information.

    :param country: The booker country for showing the best price for that user and obeying laws regarding the display of taxes and fees.
    :type country: str
    :param platform: The booker platform for showing the platform based deals and prices.
    :type platform: Platform
    :param travel_purpose: The travel purpose of the booker., defaults to None
    :type travel_purpose: TravelPurpose, optional
    :param user_groups: The user groups that the booker is a member of., defaults to None
    :type user_groups: List[UserGroups], optional
    """

    def __init__(
        self,
        country: str,
        platform: Platform,
        travel_purpose: TravelPurpose = None,
        user_groups: List[UserGroups] = None,
    ):
        self.country = self._pattern_matching(country, "^[a-z]{2}$", "country")
        self.platform = self._enum_matching(platform, Platform.list(), "platform")
        if travel_purpose is not None:
            self.travel_purpose = self._enum_matching(
                travel_purpose, TravelPurpose.list(), "travel_purpose"
            )
        if user_groups is not None:
            self.user_groups = self._define_list(user_groups, UserGroups)



# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contact_dto import ContactDto


@JsonMap({})
class ContactsDto(BaseModel):
    """Contact information of the accommodation.

    :param general: Contact information of the accommodation. It can be `null` if the data is missing., defaults to None
    :type general: ContactDto, optional
    :param reservations: Contact information of the accommodation. It can be `null` if the data is missing., defaults to None
    :type reservations: ContactDto, optional
    """

    def __init__(self, general: ContactDto = None, reservations: ContactDto = None):
        if general is not None:
            self.general = self._define_object(general, ContactDto)
        if reservations is not None:
            self.reservations = self._define_object(reservations, ContactDto)



# This file was generated by liblab | https://liblab.com/

from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


class Meals(Enum):
    """An enumeration representing different categories.

    :cvar BREAKFAST: "BREAKFAST"
    :vartype BREAKFAST: str
    :cvar DINNER: "DINNER"
    :vartype DINNER: str
    :cvar LUNCH: "LUNCH"
    :vartype LUNCH: str
    """

    BREAKFAST = "BREAKFAST"
    DINNER = "DINNER"
    LUNCH = "LUNCH"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Meals._member_map_.values()))


class Plan(Enum):
    """An enumeration representing different categories.

    :cvar ALL_INCLUSIVE: "ALL_INCLUSIVE"
    :vartype ALL_INCLUSIVE: str
    :cvar BREAKFAST_INCLUDED: "BREAKFAST_INCLUDED"
    :vartype BREAKFAST_INCLUDED: str
    :cvar FULL_BOARD: "FULL_BOARD"
    :vartype FULL_BOARD: str
    :cvar HALF_BOARD: "HALF_BOARD"
    :vartype HALF_BOARD: str
    :cvar NO_PLAN: "NO_PLAN"
    :vartype NO_PLAN: str
    """

    ALL_INCLUSIVE = "ALL_INCLUSIVE"
    BREAKFAST_INCLUDED = "BREAKFAST_INCLUDED"
    FULL_BOARD = "FULL_BOARD"
    HALF_BOARD = "HALF_BOARD"
    NO_PLAN = "NO_PLAN"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Plan._member_map_.values()))


@JsonMap({})
class MealPlanDto(BaseModel):
    """The meal plan policy for this product.

    :param meals: The meals included in the meal plan., defaults to None
    :type meals: List[Meals], optional
    :param plan: The meal plan included in this product., defaults to None
    :type plan: Plan, optional
    """

    def __init__(self, meals: List[Meals] = None, plan: Plan = None):
        if meals is not None:
            self.meals = self._define_list(meals, Meals)
        if plan is not None:
            self.plan = self._enum_matching(plan, Plan.list(), "plan")
